/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.gnome.SessionManager.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef GNOMESESSIONINTERFACE_H
#define GNOMESESSIONINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.gnome.SessionManager
 */
class OrgGnomeSessionManagerInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.gnome.SessionManager"; }

public:
    OrgGnomeSessionManagerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgGnomeSessionManagerInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<uint> Inhibit(const QString &app_id, uint toplevel_xid, const QString &reason, uint flags)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(app_id) << QVariant::fromValue(toplevel_xid) << QVariant::fromValue(reason) << QVariant::fromValue(flags);
        return asyncCallWithArgumentList(QStringLiteral("Inhibit"), argumentList);
    }

    inline QDBusPendingReply<bool> IsInhibited(uint flags)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(flags);
        return asyncCallWithArgumentList(QStringLiteral("IsInhibited"), argumentList);
    }

    inline QDBusPendingReply<> Uninhibit(uint inhibit_cookie)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(inhibit_cookie);
        return asyncCallWithArgumentList(QStringLiteral("Uninhibit"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace gnome {
    using SessionManager = ::OrgGnomeSessionManagerInterface;
  }
}

#endif
