/****************************************************************************
** Meta object code from reading C++ file 'fetcher.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/fetcher.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fetcher.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7FetcherE_t {};
} // unnamed namespace

template <> constexpr inline auto Fetcher::qt_create_metaobjectdata<qt_meta_tag_ZN7FetcherE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Fetcher",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "entryAdded",
        "",
        "entryuid",
        "entryUpdated",
        "feedUpdated",
        "feeduid",
        "feedDetailsUpdated",
        "url",
        "name",
        "image",
        "link",
        "description",
        "lastUpdated",
        "dirname",
        "feedUpdateStatusChanged",
        "status",
        "cancelFetching",
        "updateProgressChanged",
        "progress",
        "updateTotalChanged",
        "nrOfFeeds",
        "updatingChanged",
        "state",
        "error",
        "Error::Type",
        "type",
        "id",
        "errorId",
        "errorString",
        "title",
        "downloadFinished",
        "foundRedirectedUrl",
        "QUrl",
        "newUrl",
        "fetch",
        "urls",
        "fetchAll",
        "setNetworkProxy",
        "isSystemProxyDefined",
        "updateProgress",
        "updateTotal",
        "updating"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'entryAdded'
        QtMocHelpers::SignalData<void(const qint64)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Signal 'entryUpdated'
        QtMocHelpers::SignalData<void(const qint64)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Signal 'feedUpdated'
        QtMocHelpers::SignalData<void(const qint64)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 10 },
        }}),
        // Signal 'feedDetailsUpdated'
        QtMocHelpers::SignalData<void(const qint64, const QString &, const QString &, const QString &, const QString &, const QString &, const QDateTime &, const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 10 }, { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { QMetaType::QString, 14 },
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QDateTime, 17 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'feedUpdateStatusChanged'
        QtMocHelpers::SignalData<void(const qint64, bool)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 10 }, { QMetaType::Bool, 20 },
        }}),
        // Signal 'cancelFetching'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateProgressChanged'
        QtMocHelpers::SignalData<void(int)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Signal 'updateTotalChanged'
        QtMocHelpers::SignalData<void(int)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
        // Signal 'updatingChanged'
        QtMocHelpers::SignalData<void(bool)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(Error::Type, const QString &, const QString &, const int, const QString &, const QString &)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 }, { QMetaType::QString, 12 }, { QMetaType::QString, 31 }, { QMetaType::Int, 32 },
            { QMetaType::QString, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'downloadFinished'
        QtMocHelpers::SignalData<void(QString) const>(35, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'foundRedirectedUrl'
        QtMocHelpers::SignalData<void(const QUrl &, const QUrl &)>(36, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 12 }, { 0x80000000 | 37, 38 },
        }}),
        // Method 'fetch'
        QtMocHelpers::MethodData<void(const QString &)>(39, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'fetch'
        QtMocHelpers::MethodData<void(const QStringList &)>(39, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 40 },
        }}),
        // Method 'fetchAll'
        QtMocHelpers::MethodData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'image'
        QtMocHelpers::MethodData<QString(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'setNetworkProxy'
        QtMocHelpers::MethodData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'isSystemProxyDefined'
        QtMocHelpers::MethodData<bool()>(43, 6, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'updateProgress'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 6),
        // property 'updateTotal'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 7),
        // property 'updating'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Fetcher, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Fetcher::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FetcherE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FetcherE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7FetcherE_t>.metaTypes,
    nullptr
} };

void Fetcher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Fetcher *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->entryAdded((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 1: _t->entryUpdated((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 2: _t->feedUpdated((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 3: _t->feedDetailsUpdated((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8]))); break;
        case 4: _t->feedUpdateStatusChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->cancelFetching(); break;
        case 6: _t->updateProgressChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->updateTotalChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->updatingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->error((*reinterpret_cast<std::add_pointer_t<Error::Type>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 10: _t->downloadFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->foundRedirectedUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 12: _t->fetch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->fetch((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 14: _t->fetchAll(); break;
        case 15: { QString _r = _t->image((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->setNetworkProxy(); break;
        case 17: { bool _r = _t->isSystemProxyDefined();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Fetcher::*)(const qint64 )>(_a, &Fetcher::entryAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fetcher::*)(const qint64 )>(_a, &Fetcher::entryUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fetcher::*)(const qint64 )>(_a, &Fetcher::feedUpdated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fetcher::*)(const qint64 , const QString & , const QString & , const QString & , const QString & , const QString & , const QDateTime & , const QString & )>(_a, &Fetcher::feedDetailsUpdated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fetcher::*)(const qint64 , bool )>(_a, &Fetcher::feedUpdateStatusChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fetcher::*)()>(_a, &Fetcher::cancelFetching, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fetcher::*)(int )>(_a, &Fetcher::updateProgressChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fetcher::*)(int )>(_a, &Fetcher::updateTotalChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fetcher::*)(bool )>(_a, &Fetcher::updatingChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fetcher::*)(Error::Type , const QString & , const QString & , const int , const QString & , const QString & )>(_a, &Fetcher::error, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fetcher::*)(QString ) const>(_a, &Fetcher::downloadFinished, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fetcher::*)(const QUrl & , const QUrl & )>(_a, &Fetcher::foundRedirectedUrl, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->m_updateProgress; break;
        case 1: *reinterpret_cast<int*>(_v) = _t->m_updateTotal; break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->m_updating; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_updateProgress, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->updateProgressChanged(_t->m_updateProgress);
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_updateTotal, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->updateTotalChanged(_t->m_updateTotal);
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_updating, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->updatingChanged(_t->m_updating);
            break;
        default: break;
        }
    }
}

const QMetaObject *Fetcher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Fetcher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FetcherE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Fetcher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Fetcher::entryAdded(const qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Fetcher::entryUpdated(const qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Fetcher::feedUpdated(const qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Fetcher::feedDetailsUpdated(const qint64 _t1, const QString & _t2, const QString & _t3, const QString & _t4, const QString & _t5, const QString & _t6, const QDateTime & _t7, const QString & _t8)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8);
}

// SIGNAL 4
void Fetcher::feedUpdateStatusChanged(const qint64 _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void Fetcher::cancelFetching()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Fetcher::updateProgressChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Fetcher::updateTotalChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Fetcher::updatingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Fetcher::error(Error::Type _t1, const QString & _t2, const QString & _t3, const int _t4, const QString & _t5, const QString & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 10
void Fetcher::downloadFinished(QString _t1)const
{
    QMetaObject::activate<void>(const_cast< Fetcher *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Fetcher::foundRedirectedUrl(const QUrl & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}
QT_WARNING_POP
