/****************************************************************************
** Meta object code from reading C++ file 'mediaplayer2player.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kasts-26.04.2/src/kmediasession/mpris2/mediaplayer2player.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mediaplayer2player.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18MediaPlayer2PlayerE_t {};
} // unnamed namespace

template <> constexpr inline auto MediaPlayer2Player::qt_create_metaobjectdata<qt_meta_tag_ZN18MediaPlayer2PlayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MediaPlayer2Player",
        "D-Bus Interface",
        "org.mpris.MediaPlayer2.Player",
        "Seeked",
        "",
        "Position",
        "rateChanged",
        "newRate",
        "minimumRateChanged",
        "minRate",
        "maximumRateChanged",
        "maxRate",
        "volumeChanged",
        "newVol",
        "playbackStatusChanged",
        "canGoNextChanged",
        "canGoPreviousChanged",
        "canPlayChanged",
        "canPauseChanged",
        "canControlChanged",
        "canSeekChanged",
        "next",
        "previous",
        "playPause",
        "stop",
        "setRate",
        "setVolume",
        "volume",
        "Next",
        "Previous",
        "Pause",
        "PlayPause",
        "Stop",
        "Play",
        "Seek",
        "Offset",
        "SetPosition",
        "QDBusObjectPath",
        "trackId",
        "pos",
        "OpenUri",
        "uri",
        "playerPlaybackStateChanged",
        "playerPlaybackRateChanged",
        "playerSeeked",
        "position",
        "playerVolumeChanged",
        "playerCanGoNextChanged",
        "playerCanGoPreviousChanged",
        "playerCanPlayChanged",
        "playerCanPauseChanged",
        "playerCanSeekChanged",
        "playerMetaDataChanged",
        "audioPositionChanged",
        "audioDurationChanged",
        "PlaybackStatus",
        "Rate",
        "MinimumRate",
        "MaximumRate",
        "Metadata",
        "QVariantMap",
        "Volume",
        "CanGoNext",
        "CanGoPrevious",
        "CanPlay",
        "CanPause",
        "CanControl",
        "CanSeek"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Seeked'
        QtMocHelpers::SignalData<void(qlonglong)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 5 },
        }}),
        // Signal 'rateChanged'
        QtMocHelpers::SignalData<void(double)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Signal 'minimumRateChanged'
        QtMocHelpers::SignalData<void(double)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 9 },
        }}),
        // Signal 'maximumRateChanged'
        QtMocHelpers::SignalData<void(double)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 11 },
        }}),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void(double)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 13 },
        }}),
        // Signal 'playbackStatusChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canGoNextChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canGoPreviousChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canPlayChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canPauseChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canControlChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSeekChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'next'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previous'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playPause'
        QtMocHelpers::SignalData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stop'
        QtMocHelpers::SignalData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setRate'
        QtMocHelpers::SlotData<void(double)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Slot 'setVolume'
        QtMocHelpers::SlotData<void(double)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 27 },
        }}),
        // Slot 'Next'
        QtMocHelpers::SlotData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Previous'
        QtMocHelpers::SlotData<void()>(29, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Pause'
        QtMocHelpers::SlotData<void()>(30, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'PlayPause'
        QtMocHelpers::SlotData<void()>(31, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Stop'
        QtMocHelpers::SlotData<void()>(32, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Play'
        QtMocHelpers::SlotData<void()>(33, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Seek'
        QtMocHelpers::SlotData<void(qlonglong)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 35 },
        }}),
        // Slot 'SetPosition'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, qlonglong)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 }, { QMetaType::LongLong, 39 },
        }}),
        // Slot 'OpenUri'
        QtMocHelpers::SlotData<void(const QString &)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'playerPlaybackStateChanged'
        QtMocHelpers::SlotData<void()>(42, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playerPlaybackRateChanged'
        QtMocHelpers::SlotData<void()>(43, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playerSeeked'
        QtMocHelpers::SlotData<void(qint64)>(44, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 45 },
        }}),
        // Slot 'playerVolumeChanged'
        QtMocHelpers::SlotData<void()>(46, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playerCanGoNextChanged'
        QtMocHelpers::SlotData<void()>(47, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playerCanGoPreviousChanged'
        QtMocHelpers::SlotData<void()>(48, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playerCanPlayChanged'
        QtMocHelpers::SlotData<void()>(49, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playerCanPauseChanged'
        QtMocHelpers::SlotData<void()>(50, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playerCanSeekChanged'
        QtMocHelpers::SlotData<void()>(51, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playerMetaDataChanged'
        QtMocHelpers::SlotData<void()>(52, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'audioPositionChanged'
        QtMocHelpers::SlotData<void()>(53, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'audioDurationChanged'
        QtMocHelpers::SlotData<void()>(54, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'PlaybackStatus'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'Rate'
        QtMocHelpers::PropertyData<double>(56, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'MinimumRate'
        QtMocHelpers::PropertyData<double>(57, QMetaType::Double, QMC::DefaultPropertyFlags, 2),
        // property 'MaximumRate'
        QtMocHelpers::PropertyData<double>(58, QMetaType::Double, QMC::DefaultPropertyFlags, 3),
        // property 'Metadata'
        QtMocHelpers::PropertyData<QVariantMap>(59, 0x80000000 | 60, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'Volume'
        QtMocHelpers::PropertyData<double>(61, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'Position'
        QtMocHelpers::PropertyData<qlonglong>(5, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'CanGoNext'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'CanGoPrevious'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'CanPlay'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
        // property 'CanPause'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'CanControl'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'CanSeek'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MediaPlayer2Player, qt_meta_tag_ZN18MediaPlayer2PlayerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MediaPlayer2Player::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MediaPlayer2PlayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MediaPlayer2PlayerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18MediaPlayer2PlayerE_t>.metaTypes,
    nullptr
} };

void MediaPlayer2Player::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MediaPlayer2Player *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Seeked((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 1: _t->rateChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 2: _t->minimumRateChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 3: _t->maximumRateChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: _t->volumeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 5: _t->playbackStatusChanged(); break;
        case 6: _t->canGoNextChanged(); break;
        case 7: _t->canGoPreviousChanged(); break;
        case 8: _t->canPlayChanged(); break;
        case 9: _t->canPauseChanged(); break;
        case 10: _t->canControlChanged(); break;
        case 11: _t->canSeekChanged(); break;
        case 12: _t->next(); break;
        case 13: _t->previous(); break;
        case 14: _t->playPause(); break;
        case 15: _t->stop(); break;
        case 16: _t->setRate((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 17: _t->setVolume((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 18: _t->Next(); break;
        case 19: _t->Previous(); break;
        case 20: _t->Pause(); break;
        case 21: _t->PlayPause(); break;
        case 22: _t->Stop(); break;
        case 23: _t->Play(); break;
        case 24: _t->Seek((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 25: _t->SetPosition((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2]))); break;
        case 26: _t->OpenUri((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->playerPlaybackStateChanged(); break;
        case 28: _t->playerPlaybackRateChanged(); break;
        case 29: _t->playerSeeked((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 30: _t->playerVolumeChanged(); break;
        case 31: _t->playerCanGoNextChanged(); break;
        case 32: _t->playerCanGoPreviousChanged(); break;
        case 33: _t->playerCanPlayChanged(); break;
        case 34: _t->playerCanPauseChanged(); break;
        case 35: _t->playerCanSeekChanged(); break;
        case 36: _t->playerMetaDataChanged(); break;
        case 37: _t->audioPositionChanged(); break;
        case 38: _t->audioDurationChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)(qlonglong )>(_a, &MediaPlayer2Player::Seeked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)(double )>(_a, &MediaPlayer2Player::rateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)(double )>(_a, &MediaPlayer2Player::minimumRateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)(double )>(_a, &MediaPlayer2Player::maximumRateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)(double )>(_a, &MediaPlayer2Player::volumeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)()>(_a, &MediaPlayer2Player::playbackStatusChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)()>(_a, &MediaPlayer2Player::canGoNextChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)()>(_a, &MediaPlayer2Player::canGoPreviousChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)()>(_a, &MediaPlayer2Player::canPlayChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)()>(_a, &MediaPlayer2Player::canPauseChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)()>(_a, &MediaPlayer2Player::canControlChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)()>(_a, &MediaPlayer2Player::canSeekChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)()>(_a, &MediaPlayer2Player::next, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)()>(_a, &MediaPlayer2Player::previous, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)()>(_a, &MediaPlayer2Player::playPause, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer2Player::*)()>(_a, &MediaPlayer2Player::stop, 15))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->PlaybackStatus(); break;
        case 1: *reinterpret_cast<double*>(_v) = _t->Rate(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->MinimumRate(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->MaximumRate(); break;
        case 4: *reinterpret_cast<QVariantMap*>(_v) = _t->Metadata(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->Volume(); break;
        case 6: *reinterpret_cast<qlonglong*>(_v) = _t->Position(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->CanGoNext(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->CanGoPrevious(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->CanPlay(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->CanPause(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->CanControl(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->CanSeek(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setRate(*reinterpret_cast<double*>(_v)); break;
        case 5: _t->setVolume(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setPropertyPosition(*reinterpret_cast<qlonglong*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MediaPlayer2Player::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MediaPlayer2Player::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MediaPlayer2PlayerE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int MediaPlayer2Player::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void MediaPlayer2Player::Seeked(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MediaPlayer2Player::rateChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MediaPlayer2Player::minimumRateChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void MediaPlayer2Player::maximumRateChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MediaPlayer2Player::volumeChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void MediaPlayer2Player::playbackStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MediaPlayer2Player::canGoNextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MediaPlayer2Player::canGoPreviousChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MediaPlayer2Player::canPlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MediaPlayer2Player::canPauseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void MediaPlayer2Player::canControlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void MediaPlayer2Player::canSeekChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void MediaPlayer2Player::next()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void MediaPlayer2Player::previous()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void MediaPlayer2Player::playPause()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void MediaPlayer2Player::stop()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}
QT_WARNING_POP
