/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.PowerManagement.Inhibit.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef INHIBITINTERFACE_H
#define INHIBITINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.PowerManagement.Inhibit
 */
class OrgFreedesktopPowerManagementInhibitInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.PowerManagement.Inhibit"; }

public:
    OrgFreedesktopPowerManagementInhibitInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopPowerManagementInhibitInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<bool> HasInhibit()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("HasInhibit"), argumentList);
    }

    inline QDBusPendingReply<uint> Inhibit(const QString &application, const QString &reason)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(application) << QVariant::fromValue(reason);
        return asyncCallWithArgumentList(QStringLiteral("Inhibit"), argumentList);
    }

    inline QDBusPendingReply<> UnInhibit(uint cookie)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(cookie);
        return asyncCallWithArgumentList(QStringLiteral("UnInhibit"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void HasInhibitChanged(bool has_inhibit);
};

namespace org {
  namespace freedesktop {
    namespace PowerManagement {
      using Inhibit = ::OrgFreedesktopPowerManagementInhibitInterface;
    }
  }
}

#endif
