// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "networkconnectionmanagerlogging.h"


Q_LOGGING_CATEGORY(kastsNetworkConnectionManager, "org.kde.kasts.networkconnectionmanager", QtInfoMsg)

