// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_kmediasession.cpp"
#include "YK3PKTBAJD/moc_abstractmediabackend.cpp"
#include "YK3PKTBAJD/moc_qtmediabackend.cpp"
#include "YK3PKTBAJD/moc_vlcmediabackend.cpp"
#include "EWIEGA46WW/moc_metadata.cpp"
#include "66LPLJ4R2M/moc_mediaplayer2.cpp"
#include "66LPLJ4R2M/moc_mediaplayer2player.cpp"
#include "66LPLJ4R2M/moc_mpris2.cpp"
#include "OFXHEWIYU5/moc_powermanagementinterface.cpp"
