/****************************************************************************
** Meta object code from reading C++ file 'storagemanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/utils/storagemanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'storagemanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14StorageManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto StorageManager::qt_create_metaobjectdata<qt_meta_tag_ZN14StorageManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StorageManager",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "error",
        "",
        "Error::Type",
        "type",
        "url",
        "id",
        "errorId",
        "errorString",
        "title",
        "storagePathChanged",
        "path",
        "storageMoveStarted",
        "storageMoveFinished",
        "storageMoveProgressChanged",
        "progress",
        "storageMoveTotalChanged",
        "nrOfFeeds",
        "cancelStorageMove",
        "enclosureDirSizeChanged",
        "imageDirSizeChanged",
        "setStoragePath",
        "QUrl",
        "clearImageCache",
        "storageMoveProgress",
        "storageMoveTotal",
        "storagePath",
        "enclosureDirSize",
        "imageDirSize",
        "formattedEnclosureDirSize",
        "formattedImageDirSize"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'error'
        QtMocHelpers::SignalData<void(Error::Type, const QString &, const QString &, const int, const QString &, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::Int, 11 },
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'storagePathChanged'
        QtMocHelpers::SignalData<void(QString)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'storageMoveStarted'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'storageMoveFinished'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'storageMoveProgressChanged'
        QtMocHelpers::SignalData<void(int)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Signal 'storageMoveTotalChanged'
        QtMocHelpers::SignalData<void(int)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Signal 'cancelStorageMove'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enclosureDirSizeChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageDirSizeChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'setStoragePath'
        QtMocHelpers::MethodData<void(QUrl)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 9 },
        }}),
        // Method 'clearImageCache'
        QtMocHelpers::MethodData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'storageMoveProgress'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'storageMoveTotal'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'storagePath'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'enclosureDirSize'
        QtMocHelpers::PropertyData<qint64>(31, QMetaType::LongLong, QMC::DefaultPropertyFlags, 7),
        // property 'imageDirSize'
        QtMocHelpers::PropertyData<qint64>(32, QMetaType::LongLong, QMC::DefaultPropertyFlags, 8),
        // property 'formattedEnclosureDirSize'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'formattedImageDirSize'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<StorageManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject StorageManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14StorageManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14StorageManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14StorageManagerE_t>.metaTypes,
    nullptr
} };

void StorageManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StorageManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->error((*reinterpret_cast<std::add_pointer_t<Error::Type>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 1: _t->storagePathChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->storageMoveStarted(); break;
        case 3: _t->storageMoveFinished(); break;
        case 4: _t->storageMoveProgressChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->storageMoveTotalChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->cancelStorageMove(); break;
        case 7: _t->enclosureDirSizeChanged(); break;
        case 8: _t->imageDirSizeChanged(); break;
        case 9: _t->setStoragePath((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 10: _t->clearImageCache(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StorageManager::*)(Error::Type , const QString & , const QString & , const int , const QString & , const QString & )>(_a, &StorageManager::error, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageManager::*)(QString )>(_a, &StorageManager::storagePathChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageManager::*)()>(_a, &StorageManager::storageMoveStarted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageManager::*)()>(_a, &StorageManager::storageMoveFinished, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageManager::*)(int )>(_a, &StorageManager::storageMoveProgressChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageManager::*)(int )>(_a, &StorageManager::storageMoveTotalChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageManager::*)()>(_a, &StorageManager::cancelStorageMove, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageManager::*)()>(_a, &StorageManager::enclosureDirSizeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageManager::*)()>(_a, &StorageManager::imageDirSizeChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->m_storageMoveProgress; break;
        case 1: *reinterpret_cast<int*>(_v) = _t->m_storageMoveTotal; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->storagePath(); break;
        case 3: *reinterpret_cast<qint64*>(_v) = _t->enclosureDirSize(); break;
        case 4: *reinterpret_cast<qint64*>(_v) = _t->imageDirSize(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->formattedEnclosureDirSize(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->formattedImageDirSize(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_storageMoveProgress, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->storageMoveProgressChanged(_t->m_storageMoveProgress);
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_storageMoveTotal, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->storageMoveTotalChanged(_t->m_storageMoveTotal);
            break;
        default: break;
        }
    }
}

const QMetaObject *StorageManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StorageManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14StorageManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int StorageManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void StorageManager::error(Error::Type _t1, const QString & _t2, const QString & _t3, const int _t4, const QString & _t5, const QString & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 1
void StorageManager::storagePathChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void StorageManager::storageMoveStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void StorageManager::storageMoveFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void StorageManager::storageMoveProgressChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void StorageManager::storageMoveTotalChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void StorageManager::cancelStorageMove()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void StorageManager::enclosureDirSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void StorageManager::imageDirSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
