/****************************************************************************
** Meta object code from reading C++ file 'kmediasession.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kasts-26.04.2/src/kmediasession/kmediasession.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmediasession.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KMediaSessionE_t {};
} // unnamed namespace

template <> constexpr inline auto KMediaSession::qt_create_metaobjectdata<qt_meta_tag_ZN13KMediaSessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KMediaSession",
        "currentBackendChanged",
        "",
        "KMediaSession::MediaBackends",
        "backend",
        "playerNameChanged",
        "name",
        "desktopEntryNameChanged",
        "mpris2PauseInsteadOfStopChanged",
        "newState",
        "mutedChanged",
        "muted",
        "volumeChanged",
        "volume",
        "sourceChanged",
        "QUrl",
        "source",
        "mediaStatusChanged",
        "KMediaSession::MediaStatus",
        "status",
        "playbackStateChanged",
        "KMediaSession::PlaybackState",
        "state",
        "playbackRateChanged",
        "rate",
        "errorChanged",
        "KMediaSession::Error",
        "error",
        "durationChanged",
        "duration",
        "positionChanged",
        "position",
        "positionJumped",
        "seekableChanged",
        "seekable",
        "metaDataChanged",
        "MetaData*",
        "metadata",
        "canPlayChanged",
        "canPauseChanged",
        "canGoNextChanged",
        "canGoPreviousChanged",
        "nextRequested",
        "previousRequested",
        "raiseWindowRequested",
        "quitRequested",
        "setCurrentBackend",
        "setPlayerName",
        "setDesktopEntryName",
        "setMpris2PauseInsteadOfStop",
        "setMuted",
        "setVolume",
        "setSource",
        "setPosition",
        "setPlaybackRate",
        "setMetaData",
        "metaData",
        "setCanGoNext",
        "setCanGoPrevious",
        "play",
        "pause",
        "stop",
        "backendName",
        "currentBackend",
        "availableBackends",
        "QList<KMediaSession::MediaBackends>",
        "playerName",
        "desktopEntryName",
        "mpris2PauseInsteadOfStop",
        "mediaStatus",
        "MediaStatus",
        "playbackState",
        "PlaybackState",
        "playbackRate",
        "Error",
        "canPlay",
        "canPause",
        "canGoNext",
        "canGoPrevious",
        "MediaBackends",
        "Qt",
        "Vlc",
        "Gst",
        "UnknownMediaStatus",
        "NoMedia",
        "LoadingMedia",
        "LoadedMedia",
        "StalledMedia",
        "BufferingMedia",
        "BufferedMedia",
        "EndOfMedia",
        "InvalidMedia",
        "StoppedState",
        "PlayingState",
        "PausedState",
        "NoError",
        "ResourceError",
        "FormatError",
        "NetworkError",
        "AccessDeniedError",
        "ServiceMissingError"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentBackendChanged'
        QtMocHelpers::SignalData<void(KMediaSession::MediaBackends)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'playerNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'desktopEntryNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'mpris2PauseInsteadOfStopChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'mutedChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void(qreal)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 13 },
        }}),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'mediaStatusChanged'
        QtMocHelpers::SignalData<void(KMediaSession::MediaStatus)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'playbackStateChanged'
        QtMocHelpers::SignalData<void(KMediaSession::PlaybackState)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Signal 'playbackRateChanged'
        QtMocHelpers::SignalData<void(qreal)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 24 },
        }}),
        // Signal 'errorChanged'
        QtMocHelpers::SignalData<void(KMediaSession::Error)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void(qint64)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 29 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(qint64)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 31 },
        }}),
        // Signal 'positionJumped'
        QtMocHelpers::SignalData<void(qint64)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 31 },
        }}),
        // Signal 'seekableChanged'
        QtMocHelpers::SignalData<void(bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Signal 'metaDataChanged'
        QtMocHelpers::SignalData<void(MetaData *)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Signal 'canPlayChanged'
        QtMocHelpers::SignalData<void(bool)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'canPauseChanged'
        QtMocHelpers::SignalData<void(bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'canGoNextChanged'
        QtMocHelpers::SignalData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'canGoPreviousChanged'
        QtMocHelpers::SignalData<void(bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'nextRequested'
        QtMocHelpers::SignalData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previousRequested'
        QtMocHelpers::SignalData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'raiseWindowRequested'
        QtMocHelpers::SignalData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'quitRequested'
        QtMocHelpers::SignalData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCurrentBackend'
        QtMocHelpers::SlotData<void(KMediaSession::MediaBackends)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setPlayerName'
        QtMocHelpers::SlotData<void(const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'setDesktopEntryName'
        QtMocHelpers::SlotData<void(const QString &)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'setMpris2PauseInsteadOfStop'
        QtMocHelpers::SlotData<void(bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'setMuted'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setVolume'
        QtMocHelpers::SlotData<void(qreal)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 13 },
        }}),
        // Slot 'setSource'
        QtMocHelpers::SlotData<void(const QUrl &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'setPosition'
        QtMocHelpers::SlotData<void(qint64)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 31 },
        }}),
        // Slot 'setPlaybackRate'
        QtMocHelpers::SlotData<void(qreal)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 24 },
        }}),
        // Slot 'setMetaData'
        QtMocHelpers::SlotData<void(MetaData *)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 56 },
        }}),
        // Slot 'setCanGoNext'
        QtMocHelpers::SlotData<void(bool)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'setCanGoPrevious'
        QtMocHelpers::SlotData<void(bool)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'play'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'backendName'
        QtMocHelpers::MethodData<QString(KMediaSession::MediaBackends) const>(62, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'currentBackend'
        QtMocHelpers::PropertyData<KMediaSession::MediaBackends>(63, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'availableBackends'
        QtMocHelpers::PropertyData<QList<KMediaSession::MediaBackends>>(64, 0x80000000 | 65, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'playerName'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'desktopEntryName'
        QtMocHelpers::PropertyData<QString>(67, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'mpris2PauseInsteadOfStop'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'muted'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'volume'
        QtMocHelpers::PropertyData<qreal>(13, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'source'
        QtMocHelpers::PropertyData<QUrl>(16, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'mediaStatus'
        QtMocHelpers::PropertyData<enum MediaStatus>(69, 0x80000000 | 70, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'playbackState'
        QtMocHelpers::PropertyData<enum PlaybackState>(71, 0x80000000 | 72, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'playbackRate'
        QtMocHelpers::PropertyData<qreal>(73, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'error'
        QtMocHelpers::PropertyData<enum Error>(27, 0x80000000 | 74, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'position'
        QtMocHelpers::PropertyData<qint64>(31, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'duration'
        QtMocHelpers::PropertyData<qint64>(29, QMetaType::LongLong, QMC::DefaultPropertyFlags, 11),
        // property 'seekable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 14),
        // property 'metaData'
        QtMocHelpers::PropertyData<MetaData*>(56, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 15),
        // property 'canPlay'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags, 16),
        // property 'canPause'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags, 17),
        // property 'canGoNext'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'canGoPrevious'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MediaBackends'
        QtMocHelpers::EnumData<enum MediaBackends>(79, 79, QMC::EnumFlags{}).add({
            {   80, MediaBackends::Qt },
            {   81, MediaBackends::Vlc },
            {   82, MediaBackends::Gst },
        }),
        // enum 'MediaStatus'
        QtMocHelpers::EnumData<enum MediaStatus>(70, 70, QMC::EnumFlags{}).add({
            {   83, MediaStatus::UnknownMediaStatus },
            {   84, MediaStatus::NoMedia },
            {   85, MediaStatus::LoadingMedia },
            {   86, MediaStatus::LoadedMedia },
            {   87, MediaStatus::StalledMedia },
            {   88, MediaStatus::BufferingMedia },
            {   89, MediaStatus::BufferedMedia },
            {   90, MediaStatus::EndOfMedia },
            {   91, MediaStatus::InvalidMedia },
        }),
        // enum 'PlaybackState'
        QtMocHelpers::EnumData<enum PlaybackState>(72, 72, QMC::EnumFlags{}).add({
            {   92, PlaybackState::StoppedState },
            {   93, PlaybackState::PlayingState },
            {   94, PlaybackState::PausedState },
        }),
        // enum 'Error'
        QtMocHelpers::EnumData<enum Error>(74, 74, QMC::EnumFlags{}).add({
            {   95, Error::NoError },
            {   96, Error::ResourceError },
            {   97, Error::FormatError },
            {   98, Error::NetworkError },
            {   99, Error::AccessDeniedError },
            {  100, Error::ServiceMissingError },
        }),
    };
    return QtMocHelpers::metaObjectData<KMediaSession, qt_meta_tag_ZN13KMediaSessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KMediaSession::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KMediaSessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KMediaSessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KMediaSessionE_t>.metaTypes,
    nullptr
} };

void KMediaSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KMediaSession *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentBackendChanged((*reinterpret_cast<std::add_pointer_t<KMediaSession::MediaBackends>>(_a[1]))); break;
        case 1: _t->playerNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->desktopEntryNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->mpris2PauseInsteadOfStopChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->mutedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->volumeChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 6: _t->sourceChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 7: _t->mediaStatusChanged((*reinterpret_cast<std::add_pointer_t<KMediaSession::MediaStatus>>(_a[1]))); break;
        case 8: _t->playbackStateChanged((*reinterpret_cast<std::add_pointer_t<KMediaSession::PlaybackState>>(_a[1]))); break;
        case 9: _t->playbackRateChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 10: _t->errorChanged((*reinterpret_cast<std::add_pointer_t<KMediaSession::Error>>(_a[1]))); break;
        case 11: _t->durationChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 12: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 13: _t->positionJumped((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 14: _t->seekableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->metaDataChanged((*reinterpret_cast<std::add_pointer_t<MetaData*>>(_a[1]))); break;
        case 16: _t->canPlayChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->canPauseChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->canGoNextChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->canGoPreviousChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->nextRequested(); break;
        case 21: _t->previousRequested(); break;
        case 22: _t->raiseWindowRequested(); break;
        case 23: _t->quitRequested(); break;
        case 24: _t->setCurrentBackend((*reinterpret_cast<std::add_pointer_t<KMediaSession::MediaBackends>>(_a[1]))); break;
        case 25: _t->setPlayerName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->setDesktopEntryName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->setMpris2PauseInsteadOfStop((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->setMuted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->setVolume((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 30: _t->setSource((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 31: _t->setPosition((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 32: _t->setPlaybackRate((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 33: _t->setMetaData((*reinterpret_cast<std::add_pointer_t<MetaData*>>(_a[1]))); break;
        case 34: _t->setCanGoNext((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->setCanGoPrevious((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->play(); break;
        case 37: _t->pause(); break;
        case 38: _t->stop(); break;
        case 39: { QString _r = _t->backendName((*reinterpret_cast<std::add_pointer_t<KMediaSession::MediaBackends>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MetaData* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MetaData* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(KMediaSession::MediaBackends )>(_a, &KMediaSession::currentBackendChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(const QString & )>(_a, &KMediaSession::playerNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(const QString & )>(_a, &KMediaSession::desktopEntryNameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(bool )>(_a, &KMediaSession::mpris2PauseInsteadOfStopChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(bool )>(_a, &KMediaSession::mutedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(qreal )>(_a, &KMediaSession::volumeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(const QUrl & )>(_a, &KMediaSession::sourceChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(KMediaSession::MediaStatus )>(_a, &KMediaSession::mediaStatusChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(KMediaSession::PlaybackState )>(_a, &KMediaSession::playbackStateChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(qreal )>(_a, &KMediaSession::playbackRateChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(KMediaSession::Error )>(_a, &KMediaSession::errorChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(qint64 )>(_a, &KMediaSession::durationChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(qint64 )>(_a, &KMediaSession::positionChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(qint64 )>(_a, &KMediaSession::positionJumped, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(bool )>(_a, &KMediaSession::seekableChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(MetaData * )>(_a, &KMediaSession::metaDataChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(bool )>(_a, &KMediaSession::canPlayChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(bool )>(_a, &KMediaSession::canPauseChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(bool )>(_a, &KMediaSession::canGoNextChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)(bool )>(_a, &KMediaSession::canGoPreviousChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)()>(_a, &KMediaSession::nextRequested, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)()>(_a, &KMediaSession::previousRequested, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)()>(_a, &KMediaSession::raiseWindowRequested, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMediaSession::*)()>(_a, &KMediaSession::quitRequested, 23))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 15:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MetaData* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KMediaSession::MediaBackends*>(_v) = _t->currentBackend(); break;
        case 1: *reinterpret_cast<QList<KMediaSession::MediaBackends>*>(_v) = _t->availableBackends(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->playerName(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->desktopEntryName(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->mpris2PauseInsteadOfStop(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->muted(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->volume(); break;
        case 7: *reinterpret_cast<QUrl*>(_v) = _t->source(); break;
        case 8: *reinterpret_cast<enum MediaStatus*>(_v) = _t->mediaStatus(); break;
        case 9: *reinterpret_cast<enum PlaybackState*>(_v) = _t->playbackState(); break;
        case 10: *reinterpret_cast<qreal*>(_v) = _t->playbackRate(); break;
        case 11: *reinterpret_cast<enum Error*>(_v) = _t->error(); break;
        case 12: *reinterpret_cast<qint64*>(_v) = _t->position(); break;
        case 13: *reinterpret_cast<qint64*>(_v) = _t->duration(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->seekable(); break;
        case 15: *reinterpret_cast<MetaData**>(_v) = _t->metaData(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->canPlay(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->canPause(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->canGoNext(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->canGoPrevious(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCurrentBackend(*reinterpret_cast<KMediaSession::MediaBackends*>(_v)); break;
        case 2: _t->setPlayerName(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setDesktopEntryName(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setMpris2PauseInsteadOfStop(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setMuted(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setVolume(*reinterpret_cast<qreal*>(_v)); break;
        case 7: _t->setSource(*reinterpret_cast<QUrl*>(_v)); break;
        case 10: _t->setPlaybackRate(*reinterpret_cast<qreal*>(_v)); break;
        case 12: _t->setPosition(*reinterpret_cast<qint64*>(_v)); break;
        case 15: _t->setMetaData(*reinterpret_cast<MetaData**>(_v)); break;
        case 18: _t->setCanGoNext(*reinterpret_cast<bool*>(_v)); break;
        case 19: _t->setCanGoPrevious(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KMediaSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMediaSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KMediaSessionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KMediaSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void KMediaSession::currentBackendChanged(KMediaSession::MediaBackends _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KMediaSession::playerNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KMediaSession::desktopEntryNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KMediaSession::mpris2PauseInsteadOfStopChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KMediaSession::mutedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KMediaSession::volumeChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KMediaSession::sourceChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KMediaSession::mediaStatusChanged(KMediaSession::MediaStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KMediaSession::playbackStateChanged(KMediaSession::PlaybackState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KMediaSession::playbackRateChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KMediaSession::errorChanged(KMediaSession::Error _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void KMediaSession::durationChanged(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void KMediaSession::positionChanged(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void KMediaSession::positionJumped(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void KMediaSession::seekableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void KMediaSession::metaDataChanged(MetaData * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void KMediaSession::canPlayChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void KMediaSession::canPauseChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void KMediaSession::canGoNextChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void KMediaSession::canGoPreviousChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void KMediaSession::nextRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void KMediaSession::previousRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void KMediaSession::raiseWindowRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void KMediaSession::quitRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}
QT_WARNING_POP
