/****************************************************************************
** Meta object code from reading C++ file 'entry.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/entry.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'entry.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5EntryE_t {};
} // unnamed namespace

template <> constexpr inline auto Entry::qt_create_metaobjectdata<qt_meta_tag_ZN5EntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Entry",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "titleChanged",
        "title",
        "contentChanged",
        "content",
        "authorsChanged",
        "authors",
        "createdChanged",
        "created",
        "updatedChanged",
        "updated",
        "linkChanged",
        "link",
        "baseUrlChanged",
        "baseUrl",
        "readChanged",
        "read",
        "newChanged",
        "state",
        "favoriteChanged",
        "favorite",
        "hasEnclosureChanged",
        "hasEnclosure",
        "imageChanged",
        "url",
        "cachedImageChanged",
        "imagePath",
        "queueStatusChanged",
        "queueStatus",
        "adjustedContent",
        "width",
        "fontSize",
        "feed",
        "Feed*",
        "entryuid",
        "feeduid",
        "id",
        "new",
        "enclosure",
        "Enclosure*",
        "image",
        "cachedImage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'contentChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'authorsChanged'
        QtMocHelpers::SignalData<void(const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'createdChanged'
        QtMocHelpers::SignalData<void(const QDateTime &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 14 },
        }}),
        // Signal 'updatedChanged'
        QtMocHelpers::SignalData<void(const QDateTime &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 16 },
        }}),
        // Signal 'linkChanged'
        QtMocHelpers::SignalData<void(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Signal 'baseUrlChanged'
        QtMocHelpers::SignalData<void(const QString &)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Signal 'readChanged'
        QtMocHelpers::SignalData<void(bool)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'newChanged'
        QtMocHelpers::SignalData<void(bool)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Signal 'favoriteChanged'
        QtMocHelpers::SignalData<void(bool)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Signal 'hasEnclosureChanged'
        QtMocHelpers::SignalData<void(bool)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Signal 'imageChanged'
        QtMocHelpers::SignalData<void(const QString &)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Signal 'cachedImageChanged'
        QtMocHelpers::SignalData<void(const QString &)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Signal 'queueStatusChanged'
        QtMocHelpers::SignalData<void(bool)>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Method 'adjustedContent'
        QtMocHelpers::MethodData<QString(int, int)>(35, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'feed'
        QtMocHelpers::PropertyData<Feed*>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'entryuid'
        QtMocHelpers::PropertyData<qint64>(40, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'feeduid'
        QtMocHelpers::PropertyData<qint64>(41, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'id'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'content'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'authors'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'created'
        QtMocHelpers::PropertyData<QDateTime>(14, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 3),
        // property 'updated'
        QtMocHelpers::PropertyData<QDateTime>(16, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 4),
        // property 'link'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'baseUrl'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'read'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'new'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'favorite'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'enclosure'
        QtMocHelpers::PropertyData<Enclosure*>(44, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'hasEnclosure'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'image'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'cachedImage'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'queueStatus'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Entry, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Entry::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5EntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5EntryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5EntryE_t>.metaTypes,
    nullptr
} };

void Entry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Entry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->contentChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->authorsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->createdChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 4: _t->updatedChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 5: _t->linkChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->baseUrlChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->readChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->newChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->favoriteChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->hasEnclosureChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->imageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->cachedImageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->queueStatusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: { QString _r = _t->adjustedContent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(const QString & )>(_a, &Entry::titleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(const QString & )>(_a, &Entry::contentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(const QString & )>(_a, &Entry::authorsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(const QDateTime & )>(_a, &Entry::createdChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(const QDateTime & )>(_a, &Entry::updatedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(const QString & )>(_a, &Entry::linkChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(const QString & )>(_a, &Entry::baseUrlChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(bool )>(_a, &Entry::readChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(bool )>(_a, &Entry::newChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(bool )>(_a, &Entry::favoriteChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(bool )>(_a, &Entry::hasEnclosureChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(const QString & )>(_a, &Entry::imageChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(const QString & )>(_a, &Entry::cachedImageChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Entry::*)(bool )>(_a, &Entry::queueStatusChanged, 13))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 14:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Enclosure* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Feed* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Feed**>(_v) = _t->feed(); break;
        case 1: *reinterpret_cast<qint64*>(_v) = _t->entryuid(); break;
        case 2: *reinterpret_cast<qint64*>(_v) = _t->feeduid(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->content(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->authors(); break;
        case 7: *reinterpret_cast<QDateTime*>(_v) = _t->created(); break;
        case 8: *reinterpret_cast<QDateTime*>(_v) = _t->updated(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->link(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->baseUrl(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->read(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->getNew(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->favorite(); break;
        case 14: *reinterpret_cast<Enclosure**>(_v) = _t->enclosure(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->hasEnclosure(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->image(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->cachedImage(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->queueStatus(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 11: _t->setRead(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setNew(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setFavorite(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setQueueStatus(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Entry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Entry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5EntryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Entry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void Entry::titleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Entry::contentChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Entry::authorsChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Entry::createdChanged(const QDateTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Entry::updatedChanged(const QDateTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Entry::linkChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Entry::baseUrlChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Entry::readChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Entry::newChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Entry::favoriteChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Entry::hasEnclosureChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Entry::imageChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Entry::cachedImageChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Entry::queueStatusChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
