/****************************************************************************
** Meta object code from reading C++ file 'abstractmediabackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kasts-26.04.2/src/kmediasession/mediabackends/abstractmediabackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractmediabackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20AbstractMediaBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractMediaBackend::qt_create_metaobjectdata<qt_meta_tag_ZN20AbstractMediaBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractMediaBackend",
        "mutedChanged",
        "",
        "muted",
        "volumeChanged",
        "volume",
        "sourceChanged",
        "QUrl",
        "source",
        "mediaStatusChanged",
        "KMediaSession::MediaStatus",
        "status",
        "playbackStateChanged",
        "KMediaSession::PlaybackState",
        "state",
        "playbackRateChanged",
        "rate",
        "errorChanged",
        "KMediaSession::Error",
        "error",
        "durationChanged",
        "duration",
        "positionChanged",
        "position",
        "seekableChanged",
        "seekable",
        "setMuted",
        "setVolume",
        "setSource",
        "setPosition",
        "setPlaybackRate",
        "play",
        "pause",
        "stop"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mutedChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void(qreal)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 5 },
        }}),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'mediaStatusChanged'
        QtMocHelpers::SignalData<void(KMediaSession::MediaStatus)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'playbackStateChanged'
        QtMocHelpers::SignalData<void(KMediaSession::PlaybackState)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'playbackRateChanged'
        QtMocHelpers::SignalData<void(qreal)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 16 },
        }}),
        // Signal 'errorChanged'
        QtMocHelpers::SignalData<void(KMediaSession::Error)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void(qint64)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 21 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(qint64)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 23 },
        }}),
        // Signal 'seekableChanged'
        QtMocHelpers::SignalData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'setMuted'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'setVolume'
        QtMocHelpers::SlotData<void(qreal)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 5 },
        }}),
        // Slot 'setSource'
        QtMocHelpers::SlotData<void(const QUrl &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'setPosition'
        QtMocHelpers::SlotData<void(qint64)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 23 },
        }}),
        // Slot 'setPlaybackRate'
        QtMocHelpers::SlotData<void(qreal)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 16 },
        }}),
        // Slot 'play'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractMediaBackend, qt_meta_tag_ZN20AbstractMediaBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractMediaBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AbstractMediaBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AbstractMediaBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20AbstractMediaBackendE_t>.metaTypes,
    nullptr
} };

void AbstractMediaBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractMediaBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mutedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->volumeChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 2: _t->sourceChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->mediaStatusChanged((*reinterpret_cast<std::add_pointer_t<KMediaSession::MediaStatus>>(_a[1]))); break;
        case 4: _t->playbackStateChanged((*reinterpret_cast<std::add_pointer_t<KMediaSession::PlaybackState>>(_a[1]))); break;
        case 5: _t->playbackRateChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 6: _t->errorChanged((*reinterpret_cast<std::add_pointer_t<KMediaSession::Error>>(_a[1]))); break;
        case 7: _t->durationChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 8: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 9: _t->seekableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setMuted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->setVolume((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 12: _t->setSource((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 13: _t->setPosition((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 14: _t->setPlaybackRate((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 15: _t->play(); break;
        case 16: _t->pause(); break;
        case 17: _t->stop(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaBackend::*)(bool )>(_a, &AbstractMediaBackend::mutedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaBackend::*)(qreal )>(_a, &AbstractMediaBackend::volumeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaBackend::*)(const QUrl & )>(_a, &AbstractMediaBackend::sourceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaBackend::*)(KMediaSession::MediaStatus )>(_a, &AbstractMediaBackend::mediaStatusChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaBackend::*)(KMediaSession::PlaybackState )>(_a, &AbstractMediaBackend::playbackStateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaBackend::*)(qreal )>(_a, &AbstractMediaBackend::playbackRateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaBackend::*)(KMediaSession::Error )>(_a, &AbstractMediaBackend::errorChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaBackend::*)(qint64 )>(_a, &AbstractMediaBackend::durationChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaBackend::*)(qint64 )>(_a, &AbstractMediaBackend::positionChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaBackend::*)(bool )>(_a, &AbstractMediaBackend::seekableChanged, 9))
            return;
    }
}

const QMetaObject *AbstractMediaBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractMediaBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AbstractMediaBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractMediaBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void AbstractMediaBackend::mutedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AbstractMediaBackend::volumeChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AbstractMediaBackend::sourceChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AbstractMediaBackend::mediaStatusChanged(KMediaSession::MediaStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AbstractMediaBackend::playbackStateChanged(KMediaSession::PlaybackState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AbstractMediaBackend::playbackRateChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void AbstractMediaBackend::errorChanged(KMediaSession::Error _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void AbstractMediaBackend::durationChanged(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void AbstractMediaBackend::positionChanged(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void AbstractMediaBackend::seekableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
