/****************************************************************************
** Meta object code from reading C++ file 'abstractepisodeproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/models/abstractepisodeproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractepisodeproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25AbstractEpisodeProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractEpisodeProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN25AbstractEpisodeProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractEpisodeProxyModel",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "filterTypeChanged",
        "searchFilterChanged",
        "searchFlagsChanged",
        "sortTypeChanged",
        "getFilterName",
        "FilterType",
        "type",
        "getSearchFlagName",
        "SearchFlag",
        "flag",
        "getSortName",
        "SortType",
        "getSortIconName",
        "createSelection",
        "QItemSelection",
        "rowa",
        "rowb",
        "filterType",
        "filterName",
        "searchFilter",
        "searchFlags",
        "SearchFlags",
        "sortType",
        "NoFilter",
        "ReadFilter",
        "NotReadFilter",
        "NewFilter",
        "NotNewFilter",
        "FavoriteFilter",
        "NotFavoriteFilter",
        "TitleFlag",
        "ContentFlag",
        "FeedNameFlag",
        "DateDescending",
        "DateAscending"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterTypeChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'searchFilterChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'searchFlagsChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortTypeChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'getFilterName'
        QtMocHelpers::MethodData<QString(enum FilterType)>(11, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'getSearchFlagName'
        QtMocHelpers::MethodData<QString(enum SearchFlag)>(14, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Method 'getSortName'
        QtMocHelpers::MethodData<QString(enum SortType)>(17, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 18, 13 },
        }}),
        // Method 'getSortIconName'
        QtMocHelpers::MethodData<QString(enum SortType)>(19, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 18, 13 },
        }}),
        // Method 'createSelection'
        QtMocHelpers::MethodData<QItemSelection(int, int)>(20, 6, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 22 }, { QMetaType::Int, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filterType'
        QtMocHelpers::PropertyData<enum FilterType>(24, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'filterName'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'searchFilter'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'searchFlags'
        QtMocHelpers::PropertyData<SearchFlags>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'sortType'
        QtMocHelpers::PropertyData<enum SortType>(29, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'FilterType'
        QtMocHelpers::EnumData<enum FilterType>(12, 12, QMC::EnumFlags{}).add({
            {   30, FilterType::NoFilter },
            {   31, FilterType::ReadFilter },
            {   32, FilterType::NotReadFilter },
            {   33, FilterType::NewFilter },
            {   34, FilterType::NotNewFilter },
            {   35, FilterType::FavoriteFilter },
            {   36, FilterType::NotFavoriteFilter },
        }),
        // enum 'SearchFlag'
        QtMocHelpers::EnumData<enum SearchFlag>(15, 15, QMC::EnumFlags{}).add({
            {   37, SearchFlag::TitleFlag },
            {   38, SearchFlag::ContentFlag },
            {   39, SearchFlag::FeedNameFlag },
        }),
        // flag 'SearchFlags'
        QtMocHelpers::EnumData<SearchFlags>(28, 15, QMC::EnumIsFlag).add({
            {   37, SearchFlag::TitleFlag },
            {   38, SearchFlag::ContentFlag },
            {   39, SearchFlag::FeedNameFlag },
        }),
        // enum 'SortType'
        QtMocHelpers::EnumData<enum SortType>(18, 18, QMC::EnumFlags{}).add({
            {   40, SortType::DateDescending },
            {   41, SortType::DateAscending },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<AbstractEpisodeProxyModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AbstractEpisodeProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25AbstractEpisodeProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25AbstractEpisodeProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25AbstractEpisodeProxyModelE_t>.metaTypes,
    nullptr
} };

void AbstractEpisodeProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractEpisodeProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterTypeChanged(); break;
        case 1: _t->searchFilterChanged(); break;
        case 2: _t->searchFlagsChanged(); break;
        case 3: _t->sortTypeChanged(); break;
        case 4: { QString _r = _t->getFilterName((*reinterpret_cast<std::add_pointer_t<enum FilterType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->getSearchFlagName((*reinterpret_cast<std::add_pointer_t<enum SearchFlag>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->getSortName((*reinterpret_cast<std::add_pointer_t<enum SortType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->getSortIconName((*reinterpret_cast<std::add_pointer_t<enum SortType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QItemSelection _r = _t->createSelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QItemSelection*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractEpisodeProxyModel::*)()>(_a, &AbstractEpisodeProxyModel::filterTypeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractEpisodeProxyModel::*)()>(_a, &AbstractEpisodeProxyModel::searchFilterChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractEpisodeProxyModel::*)()>(_a, &AbstractEpisodeProxyModel::searchFlagsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractEpisodeProxyModel::*)()>(_a, &AbstractEpisodeProxyModel::sortTypeChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum FilterType*>(_v) = _t->filterType(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->filterName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->searchFilter(); break;
        case 3: QtMocHelpers::assignFlags<SearchFlags>(_v, _t->searchFlags()); break;
        case 4: *reinterpret_cast<enum SortType*>(_v) = _t->sortType(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFilterType(*reinterpret_cast<enum FilterType*>(_v)); break;
        case 2: _t->setSearchFilter(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setSearchFlags(*reinterpret_cast<SearchFlags*>(_v)); break;
        case 4: _t->setSortType(*reinterpret_cast<enum SortType*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AbstractEpisodeProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractEpisodeProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25AbstractEpisodeProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int AbstractEpisodeProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void AbstractEpisodeProxyModel::filterTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AbstractEpisodeProxyModel::searchFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AbstractEpisodeProxyModel::searchFlagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AbstractEpisodeProxyModel::sortTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
