// /qt/qml/org/kde/kasts/qml/Settings/StorageDirDialog.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_kasts_qml_Settings_StorageDirDialog_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x84,0x5,0x0,0x0,0xb6,0xba,0x1,0x14,
0xf9,0xe,0xb5,0xf4,0xcd,0xd3,0x59,0x3b,
0x8a,0xb8,0x5,0xbc,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x30,0x2,0x0,0x0,
0x3,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd4,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0xd4,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xa8,0x4,0x0,0x0,
0x0,0x1,0x0,0x0,0x58,0x1,0x0,0x0,
0xa8,0x1,0x0,0x0,0x20,0x2,0x0,0x0,
0xb3,0x0,0x0,0x0,0xc0,0x0,0x0,0x0,
0x33,0x0,0x0,0x0,0xd0,0x0,0x0,0x0,
0xb3,0x0,0x0,0x0,0xf3,0x0,0x0,0x0,
0xe4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0xc,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x12,0xa,0x18,0x7,
0x2e,0x0,0x3c,0x1,0x80,0x7,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0xd,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x2,0x3c,0x3,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0xff,0xff,0xff,0xff,0xb,0x0,0x0,0x0,
0xe,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0xca,0x2e,0x4,0x18,
0x7,0x2e,0x5,0x18,0xa,0xac,0x6,0x7,
0x1,0xa,0x18,0x6,0xd4,0x16,0x6,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x70,0x2,0x0,0x0,0x78,0x2,0x0,0x0,
0xa0,0x2,0x0,0x0,0xc0,0x2,0x0,0x0,
0xe0,0x2,0x0,0x0,0x0,0x3,0x0,0x0,
0x40,0x3,0x0,0x0,0x58,0x3,0x0,0x0,
0x90,0x3,0x0,0x0,0xb0,0x3,0x0,0x0,
0xe8,0x3,0x0,0x0,0x0,0x4,0x0,0x0,
0x28,0x4,0x0,0x0,0x48,0x4,0x0,0x0,
0x68,0x4,0x0,0x0,0x90,0x4,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x2e,0x0,0x6c,0x0,0x61,0x0,0x62,0x0,
0x73,0x0,0x2e,0x0,0x70,0x0,0x6c,0x0,
0x61,0x0,0x74,0x0,0x66,0x0,0x6f,0x0,
0x72,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x61,0x0,
0x73,0x0,0x74,0x0,0x73,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x46,0x0,0x6f,0x0,
0x6c,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x44,0x0,0x69,0x0,0x61,0x0,0x6c,0x0,
0x6f,0x0,0x67,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x63,0x0,0x75,0x0,
0x72,0x0,0x72,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x46,0x0,0x6f,0x0,0x6c,0x0,
0x64,0x0,0x65,0x0,0x72,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x63,0x0,0x75,0x0,0x72,0x0,
0x72,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,
0x46,0x0,0x6f,0x0,0x6c,0x0,0x64,0x0,
0x65,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x6f,0x0,0x70,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x70,0x0,0x74,0x0,
0x69,0x0,0x6f,0x0,0x6e,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x41,0x0,0x63,0x0,0x63,0x0,0x65,0x0,
0x70,0x0,0x74,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x41,0x0,
0x63,0x0,0x63,0x0,0x65,0x0,0x70,0x0,
0x74,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x65,0x0,0x3a,0x0,0x2f,0x0,
0x2f,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x53,0x0,0x74,0x0,
0x6f,0x0,0x72,0x0,0x61,0x0,0x67,0x0,
0x65,0x0,0x4d,0x0,0x61,0x0,0x6e,0x0,
0x61,0x0,0x67,0x0,0x65,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x73,0x0,0x74,0x0,
0x6f,0x0,0x72,0x0,0x61,0x0,0x67,0x0,
0x65,0x0,0x50,0x0,0x61,0x0,0x74,0x0,
0x68,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x53,0x0,0x68,0x0,
0x6f,0x0,0x77,0x0,0x44,0x0,0x69,0x0,
0x72,0x0,0x73,0x0,0x4f,0x0,0x6e,0x0,
0x6c,0x0,0x79,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x73,0x0,0x65,0x0,
0x74,0x0,0x53,0x0,0x74,0x0,0x6f,0x0,
0x72,0x0,0x61,0x0,0x67,0x0,0x65,0x0,
0x50,0x0,0x61,0x0,0x74,0x0,0x68,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x66,0x0,0x6f,0x0,
0x6c,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x38,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x7,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x3c,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x3,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9c,0x0,0x0,0x0,
0xb,0x0,0x10,0x0,0x0,0x0,0x0,0x0,
0x9c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x50,0x0,0xe,0x0,0x10,0x1,
0x6,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x50,0x0,0xd,0x0,0xe0,0x0,
0x4,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x50,0x0,0xc,0x0,0x40,0x1,
0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QUrl>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for currentFolder at line 12, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_4, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_4 = nullptr;
QString v2_0;
QString v2_6;
QUrl v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadRuntimeString
s.v2_0 = QStringLiteral("file://");
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadSingletonLookup(0, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadSingletonLookup(0, QQmlPrivate::AOTCompiledContext::InvalidStringId);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
{
}
// generate_GetLookup
{
QVariant retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->getObjectLookup(1, s.v2_4, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initGetObjectLookupAsVariant(1, s.v2_4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
s.v2_6 = aotContext->engine->fromVariant<QString>(std::move(retrieved));
}
{
}
// generate_Add
s.v2_8 = QUrl(QString(std::move(s.v2_0) + std::move(s.v2_6)));
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = std::move(s.v2_8);
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QFileDialogOptions::FileDialogOptions"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for options at line 13, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
int v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getEnumLookup(3, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetEnumLookup(3, []() { static const auto t = QMetaType::fromName("QFileDialogOptions"); return t; }().metaObject(), "FileDialogOption", "ShowDirsOnly");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QFileDialogOptions::FileDialogOptions"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &s.v2_2);
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onAccepted at line 14, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_1, markStack);
    aotContext->mark(v2_5, markStack);
    aotContext->mark(v2_9, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_1 = nullptr;
QVariant v2_5;
QVariant v2_9;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
while (!aotContext->loadSingletonLookup(4, &s.v2_1)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
aotContext->initLoadSingletonLookup(4, QQmlPrivate::AOTCompiledContext::InvalidStringId);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
{
QUrl retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(7);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(5, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(7);
#endif
aotContext->initLoadScopeObjectPropertyLookup(5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_5 = QVariant::fromValue(std::move(retrieved));
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.v2_5};
    return aotContext->callObjectPropertyLookup(6, s.v2_1, args, 1);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookupAsVariant(6, s.v2_1);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_9 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_9);
}
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
