#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_kasts_qml_Main_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_FeedListPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_FeedListGridView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_EntryPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_FeedDetailsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_AddFeedSheet_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_FeedListDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Mobile_MinimizedPlayerControls_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Mobile_MobilePlayerControls_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_VolumeSlider_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Mobile_FooterBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Mobile_BottomToolbar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_QueuePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_EpisodeListPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_DownloadListPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_ErrorList_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_ErrorListOverlay_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_GenericHeader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_GenericEntryDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_GenericEntryListView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_DiscoverPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_ImageWithFallback_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_UpdateNotification_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_KastsGlobalDrawer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Desktop_HeaderBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Desktop_DesktopPlayerControls_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_PlaybackRateMenu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_PlaybackRateCustomizerDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_ErrorNotification_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_ConnectionCheckAction_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_ChapterListDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_SyncPasswordOverlay_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Settings_SettingsView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Settings_GeneralSettingsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Settings_AppearanceSettingsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Settings_StorageDirDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Settings_NetworkSettingsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Settings_StorageSettingsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Settings_SynchronizationSettingsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_Settings_ErrorListPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_SleepTimerDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_FullScreenImage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_GlobalSearchField_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_SearchBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_FilterInlineMessage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_kasts_qml_ChapterSlider_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Main.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Main_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/FeedListPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_FeedListPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/FeedListGridView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_FeedListGridView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/EntryPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_EntryPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/FeedDetailsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_FeedDetailsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/AddFeedSheet.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_AddFeedSheet_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/FeedListDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_FeedListDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Mobile/MinimizedPlayerControls.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Mobile_MinimizedPlayerControls_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Mobile/MobilePlayerControls.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Mobile_MobilePlayerControls_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/VolumeSlider.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_VolumeSlider_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Mobile/FooterBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Mobile_FooterBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Mobile/BottomToolbar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Mobile_BottomToolbar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/QueuePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_QueuePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/EpisodeListPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_EpisodeListPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/DownloadListPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_DownloadListPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/ErrorList.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_ErrorList_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/ErrorListOverlay.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_ErrorListOverlay_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/GenericHeader.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_GenericHeader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/GenericEntryDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_GenericEntryDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/GenericEntryListView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_GenericEntryListView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/DiscoverPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_DiscoverPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/ImageWithFallback.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_ImageWithFallback_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/UpdateNotification.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_UpdateNotification_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/KastsGlobalDrawer.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_KastsGlobalDrawer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Desktop/HeaderBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Desktop_HeaderBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Desktop/DesktopPlayerControls.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Desktop_DesktopPlayerControls_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/PlaybackRateMenu.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_PlaybackRateMenu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/PlaybackRateCustomizerDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_PlaybackRateCustomizerDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/ErrorNotification.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_ErrorNotification_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/ConnectionCheckAction.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_ConnectionCheckAction_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/ChapterListDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_ChapterListDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/SyncPasswordOverlay.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_SyncPasswordOverlay_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Settings/SettingsView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Settings_SettingsView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Settings/GeneralSettingsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Settings_GeneralSettingsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Settings/AppearanceSettingsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Settings_AppearanceSettingsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Settings/StorageDirDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Settings_StorageDirDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Settings/NetworkSettingsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Settings_NetworkSettingsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Settings/StorageSettingsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Settings_StorageSettingsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Settings/SynchronizationSettingsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Settings_SynchronizationSettingsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/Settings/ErrorListPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_Settings_ErrorListPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/SleepTimerDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_SleepTimerDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/FullScreenImage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_FullScreenImage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/GlobalSearchField.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_GlobalSearchField_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/SearchBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_SearchBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/FilterInlineMessage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_FilterInlineMessage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/kasts/qml/ChapterSlider.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_kasts_qml_ChapterSlider_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_kasts)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_kasts))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_kasts)() {
    return 1;
}
