/****************************************************************************
** Meta object code from reading C++ file 'settingsmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../settingsmanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settingsmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SettingsManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto SettingsManager::qt_create_metaobjectdata<qt_meta_tag_ZN15SettingsManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SettingsManager",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "prioritizeStreamingChanged",
        "",
        "continuePlayingNextEntryChanged",
        "adjustTimeLeftChanged",
        "refreshOnStartupChanged",
        "doFullUpdateChanged",
        "autoQueueChanged",
        "autoDownloadChanged",
        "autoFeedUpdateIntervalChanged",
        "autoDeleteOnPlayedChanged",
        "markAsPlayedBeforeEndChanged",
        "resetPositionOnPlayedChanged",
        "markUnreadOnNewFeedChanged",
        "markUnreadOnNewFeedCustomAmountChanged",
        "toggleRemainingTimeChanged",
        "articleFontSizeChanged",
        "StoragePathChanged",
        "alwaysShowFeedTitlesChanged",
        "showEpisodeImageChanged",
        "showPodcastTitleChanged",
        "showTrayIconChanged",
        "trayIconTypeChanged",
        "minimizeToTrayChanged",
        "articleFontUseSystemChanged",
        "interfaceModeChanged",
        "mediabackendChanged",
        "playbackRatesChanged",
        "skipForwardChanged",
        "skipBackwardChanged",
        "maximumParallelEpisodeDownloadsChanged",
        "checkNetworkStatusChanged",
        "allowMeteredFeedUpdatesChanged",
        "allowMeteredEpisodeDownloadsChanged",
        "allowMeteredImageDownloadsChanged",
        "allowMeteredStreamingChanged",
        "sleepTimerValueChanged",
        "sleepTimerUnitsChanged",
        "syncEnabledChanged",
        "syncWhenUpdatingFeedsChanged",
        "syncWhenPlayerstateChangesChanged",
        "syncProviderChanged",
        "syncHostnameChanged",
        "syncUsernameChanged",
        "syncDeviceChanged",
        "syncDeviceNameChanged",
        "ProxyTypeChanged",
        "ProxyHostChanged",
        "ProxyPortChanged",
        "ProxyUserChanged",
        "ProxyPasswordChanged",
        "prioritizeStreaming",
        "isPrioritizeStreamingImmutable",
        "defaultPrioritizeStreamingValue",
        "continuePlayingNextEntry",
        "isContinuePlayingNextEntryImmutable",
        "defaultContinuePlayingNextEntryValue",
        "adjustTimeLeft",
        "isAdjustTimeLeftImmutable",
        "defaultAdjustTimeLeftValue",
        "refreshOnStartup",
        "isRefreshOnStartupImmutable",
        "defaultRefreshOnStartupValue",
        "doFullUpdate",
        "isDoFullUpdateImmutable",
        "defaultDoFullUpdateValue",
        "autoQueue",
        "isAutoQueueImmutable",
        "defaultAutoQueueValue",
        "autoDownload",
        "isAutoDownloadImmutable",
        "defaultAutoDownloadValue",
        "autoFeedUpdateInterval",
        "isAutoFeedUpdateIntervalImmutable",
        "defaultAutoFeedUpdateIntervalValue",
        "autoDeleteOnPlayed",
        "isAutoDeleteOnPlayedImmutable",
        "defaultAutoDeleteOnPlayedValue",
        "markAsPlayedBeforeEnd",
        "isMarkAsPlayedBeforeEndImmutable",
        "defaultMarkAsPlayedBeforeEndValue",
        "resetPositionOnPlayed",
        "isResetPositionOnPlayedImmutable",
        "defaultResetPositionOnPlayedValue",
        "markUnreadOnNewFeed",
        "isMarkUnreadOnNewFeedImmutable",
        "defaultMarkUnreadOnNewFeedValue",
        "markUnreadOnNewFeedCustomAmount",
        "isMarkUnreadOnNewFeedCustomAmountImmutable",
        "defaultMarkUnreadOnNewFeedCustomAmountValue",
        "toggleRemainingTime",
        "isToggleRemainingTimeImmutable",
        "defaultToggleRemainingTimeValue",
        "articleFontSize",
        "isArticleFontSizeImmutable",
        "defaultArticleFontSizeValue",
        "storagePath",
        "QUrl",
        "isStoragePathImmutable",
        "alwaysShowFeedTitles",
        "isAlwaysShowFeedTitlesImmutable",
        "defaultAlwaysShowFeedTitlesValue",
        "showEpisodeImage",
        "isShowEpisodeImageImmutable",
        "defaultShowEpisodeImageValue",
        "showPodcastTitle",
        "isShowPodcastTitleImmutable",
        "defaultShowPodcastTitleValue",
        "showTrayIcon",
        "isShowTrayIconImmutable",
        "defaultShowTrayIconValue",
        "trayIconType",
        "isTrayIconTypeImmutable",
        "defaultTrayIconTypeValue",
        "minimizeToTray",
        "isMinimizeToTrayImmutable",
        "defaultMinimizeToTrayValue",
        "articleFontUseSystem",
        "isArticleFontUseSystemImmutable",
        "defaultArticleFontUseSystemValue",
        "interfaceMode",
        "isInterfaceModeImmutable",
        "defaultInterfaceModeValue",
        "mediabackend",
        "isMediabackendImmutable",
        "defaultMediabackendValue",
        "playbackRates",
        "QList<int>",
        "isPlaybackRatesImmutable",
        "defaultPlaybackRatesValue",
        "skipForward",
        "isSkipForwardImmutable",
        "defaultSkipForwardValue",
        "skipBackward",
        "isSkipBackwardImmutable",
        "defaultSkipBackwardValue",
        "maximumParallelEpisodeDownloads",
        "isMaximumParallelEpisodeDownloadsImmutable",
        "defaultMaximumParallelEpisodeDownloadsValue",
        "checkNetworkStatus",
        "isCheckNetworkStatusImmutable",
        "defaultCheckNetworkStatusValue",
        "allowMeteredFeedUpdates",
        "isAllowMeteredFeedUpdatesImmutable",
        "defaultAllowMeteredFeedUpdatesValue",
        "allowMeteredEpisodeDownloads",
        "isAllowMeteredEpisodeDownloadsImmutable",
        "defaultAllowMeteredEpisodeDownloadsValue",
        "allowMeteredImageDownloads",
        "isAllowMeteredImageDownloadsImmutable",
        "defaultAllowMeteredImageDownloadsValue",
        "allowMeteredStreaming",
        "isAllowMeteredStreamingImmutable",
        "defaultAllowMeteredStreamingValue",
        "sleepTimerValue",
        "isSleepTimerValueImmutable",
        "defaultSleepTimerValueValue",
        "sleepTimerUnits",
        "isSleepTimerUnitsImmutable",
        "defaultSleepTimerUnitsValue",
        "syncEnabled",
        "isSyncEnabledImmutable",
        "defaultSyncEnabledValue",
        "syncWhenUpdatingFeeds",
        "isSyncWhenUpdatingFeedsImmutable",
        "defaultSyncWhenUpdatingFeedsValue",
        "syncWhenPlayerstateChanges",
        "isSyncWhenPlayerstateChangesImmutable",
        "defaultSyncWhenPlayerstateChangesValue",
        "syncProvider",
        "isSyncProviderImmutable",
        "defaultSyncProviderValue",
        "syncHostname",
        "isSyncHostnameImmutable",
        "syncUsername",
        "isSyncUsernameImmutable",
        "syncDevice",
        "isSyncDeviceImmutable",
        "syncDeviceName",
        "isSyncDeviceNameImmutable",
        "proxyType",
        "isProxyTypeImmutable",
        "proxyHost",
        "isProxyHostImmutable",
        "defaultProxyHostValue",
        "proxyPort",
        "isProxyPortImmutable",
        "defaultProxyPortValue",
        "proxyUser",
        "isProxyUserImmutable",
        "proxyPassword",
        "isProxyPasswordImmutable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'prioritizeStreamingChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'continuePlayingNextEntryChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adjustTimeLeftChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshOnStartupChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doFullUpdateChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoQueueChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoDownloadChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoFeedUpdateIntervalChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoDeleteOnPlayedChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'markAsPlayedBeforeEndChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resetPositionOnPlayedChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'markUnreadOnNewFeedChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'markUnreadOnNewFeedCustomAmountChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toggleRemainingTimeChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'articleFontSizeChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StoragePathChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alwaysShowFeedTitlesChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showEpisodeImageChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showPodcastTitleChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showTrayIconChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trayIconTypeChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimizeToTrayChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'articleFontUseSystemChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interfaceModeChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediabackendChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playbackRatesChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'skipForwardChanged'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'skipBackwardChanged'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumParallelEpisodeDownloadsChanged'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'checkNetworkStatusChanged'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allowMeteredFeedUpdatesChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allowMeteredEpisodeDownloadsChanged'
        QtMocHelpers::SignalData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allowMeteredImageDownloadsChanged'
        QtMocHelpers::SignalData<void()>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allowMeteredStreamingChanged'
        QtMocHelpers::SignalData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sleepTimerValueChanged'
        QtMocHelpers::SignalData<void()>(40, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sleepTimerUnitsChanged'
        QtMocHelpers::SignalData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncEnabledChanged'
        QtMocHelpers::SignalData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncWhenUpdatingFeedsChanged'
        QtMocHelpers::SignalData<void()>(43, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncWhenPlayerstateChangesChanged'
        QtMocHelpers::SignalData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncProviderChanged'
        QtMocHelpers::SignalData<void()>(45, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncHostnameChanged'
        QtMocHelpers::SignalData<void()>(46, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncUsernameChanged'
        QtMocHelpers::SignalData<void()>(47, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncDeviceChanged'
        QtMocHelpers::SignalData<void()>(48, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncDeviceNameChanged'
        QtMocHelpers::SignalData<void()>(49, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProxyTypeChanged'
        QtMocHelpers::SignalData<void()>(50, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProxyHostChanged'
        QtMocHelpers::SignalData<void()>(51, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProxyPortChanged'
        QtMocHelpers::SignalData<void()>(52, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProxyUserChanged'
        QtMocHelpers::SignalData<void()>(53, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProxyPasswordChanged'
        QtMocHelpers::SignalData<void()>(54, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'prioritizeStreaming'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isPrioritizeStreamingImmutable'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPrioritizeStreamingValue'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'continuePlayingNextEntry'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isContinuePlayingNextEntryImmutable'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultContinuePlayingNextEntryValue'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'adjustTimeLeft'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isAdjustTimeLeftImmutable'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAdjustTimeLeftValue'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'refreshOnStartup'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isRefreshOnStartupImmutable'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRefreshOnStartupValue'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'doFullUpdate'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isDoFullUpdateImmutable'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDoFullUpdateValue'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoQueue'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isAutoQueueImmutable'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoQueueValue'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoDownload'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isAutoDownloadImmutable'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoDownloadValue'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoFeedUpdateInterval'
        QtMocHelpers::PropertyData<int>(76, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isAutoFeedUpdateIntervalImmutable'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoFeedUpdateIntervalValue'
        QtMocHelpers::PropertyData<int>(78, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoDeleteOnPlayed'
        QtMocHelpers::PropertyData<int>(79, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isAutoDeleteOnPlayedImmutable'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoDeleteOnPlayedValue'
        QtMocHelpers::PropertyData<int>(81, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'markAsPlayedBeforeEnd'
        QtMocHelpers::PropertyData<int>(82, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isMarkAsPlayedBeforeEndImmutable'
        QtMocHelpers::PropertyData<bool>(83, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMarkAsPlayedBeforeEndValue'
        QtMocHelpers::PropertyData<int>(84, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'resetPositionOnPlayed'
        QtMocHelpers::PropertyData<bool>(85, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isResetPositionOnPlayedImmutable'
        QtMocHelpers::PropertyData<bool>(86, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultResetPositionOnPlayedValue'
        QtMocHelpers::PropertyData<bool>(87, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'markUnreadOnNewFeed'
        QtMocHelpers::PropertyData<int>(88, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isMarkUnreadOnNewFeedImmutable'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMarkUnreadOnNewFeedValue'
        QtMocHelpers::PropertyData<int>(90, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'markUnreadOnNewFeedCustomAmount'
        QtMocHelpers::PropertyData<int>(91, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isMarkUnreadOnNewFeedCustomAmountImmutable'
        QtMocHelpers::PropertyData<bool>(92, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMarkUnreadOnNewFeedCustomAmountValue'
        QtMocHelpers::PropertyData<int>(93, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'toggleRemainingTime'
        QtMocHelpers::PropertyData<bool>(94, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isToggleRemainingTimeImmutable'
        QtMocHelpers::PropertyData<bool>(95, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultToggleRemainingTimeValue'
        QtMocHelpers::PropertyData<bool>(96, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'articleFontSize'
        QtMocHelpers::PropertyData<int>(97, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isArticleFontSizeImmutable'
        QtMocHelpers::PropertyData<bool>(98, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultArticleFontSizeValue'
        QtMocHelpers::PropertyData<int>(99, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'storagePath'
        QtMocHelpers::PropertyData<QUrl>(100, 0x80000000 | 101, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 15),
        // property 'isStoragePathImmutable'
        QtMocHelpers::PropertyData<bool>(102, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alwaysShowFeedTitles'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isAlwaysShowFeedTitlesImmutable'
        QtMocHelpers::PropertyData<bool>(104, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAlwaysShowFeedTitlesValue'
        QtMocHelpers::PropertyData<bool>(105, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showEpisodeImage'
        QtMocHelpers::PropertyData<bool>(106, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isShowEpisodeImageImmutable'
        QtMocHelpers::PropertyData<bool>(107, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowEpisodeImageValue'
        QtMocHelpers::PropertyData<bool>(108, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showPodcastTitle'
        QtMocHelpers::PropertyData<bool>(109, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isShowPodcastTitleImmutable'
        QtMocHelpers::PropertyData<bool>(110, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowPodcastTitleValue'
        QtMocHelpers::PropertyData<bool>(111, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showTrayIcon'
        QtMocHelpers::PropertyData<bool>(112, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isShowTrayIconImmutable'
        QtMocHelpers::PropertyData<bool>(113, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowTrayIconValue'
        QtMocHelpers::PropertyData<bool>(114, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'trayIconType'
        QtMocHelpers::PropertyData<int>(115, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isTrayIconTypeImmutable'
        QtMocHelpers::PropertyData<bool>(116, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTrayIconTypeValue'
        QtMocHelpers::PropertyData<int>(117, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'minimizeToTray'
        QtMocHelpers::PropertyData<bool>(118, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isMinimizeToTrayImmutable'
        QtMocHelpers::PropertyData<bool>(119, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMinimizeToTrayValue'
        QtMocHelpers::PropertyData<bool>(120, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'articleFontUseSystem'
        QtMocHelpers::PropertyData<bool>(121, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isArticleFontUseSystemImmutable'
        QtMocHelpers::PropertyData<bool>(122, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultArticleFontUseSystemValue'
        QtMocHelpers::PropertyData<bool>(123, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'interfaceMode'
        QtMocHelpers::PropertyData<int>(124, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'isInterfaceModeImmutable'
        QtMocHelpers::PropertyData<bool>(125, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInterfaceModeValue'
        QtMocHelpers::PropertyData<int>(126, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mediabackend'
        QtMocHelpers::PropertyData<int>(127, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'isMediabackendImmutable'
        QtMocHelpers::PropertyData<bool>(128, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMediabackendValue'
        QtMocHelpers::PropertyData<int>(129, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'playbackRates'
        QtMocHelpers::PropertyData<QList<int>>(130, 0x80000000 | 131, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 25),
        // property 'isPlaybackRatesImmutable'
        QtMocHelpers::PropertyData<bool>(132, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPlaybackRatesValue'
        QtMocHelpers::PropertyData<QList<int>>(133, 0x80000000 | 131, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'skipForward'
        QtMocHelpers::PropertyData<uint>(134, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'isSkipForwardImmutable'
        QtMocHelpers::PropertyData<bool>(135, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSkipForwardValue'
        QtMocHelpers::PropertyData<uint>(136, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'skipBackward'
        QtMocHelpers::PropertyData<uint>(137, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'isSkipBackwardImmutable'
        QtMocHelpers::PropertyData<bool>(138, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSkipBackwardValue'
        QtMocHelpers::PropertyData<uint>(139, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maximumParallelEpisodeDownloads'
        QtMocHelpers::PropertyData<int>(140, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isMaximumParallelEpisodeDownloadsImmutable'
        QtMocHelpers::PropertyData<bool>(141, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMaximumParallelEpisodeDownloadsValue'
        QtMocHelpers::PropertyData<int>(142, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'checkNetworkStatus'
        QtMocHelpers::PropertyData<bool>(143, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'isCheckNetworkStatusImmutable'
        QtMocHelpers::PropertyData<bool>(144, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCheckNetworkStatusValue'
        QtMocHelpers::PropertyData<bool>(145, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'allowMeteredFeedUpdates'
        QtMocHelpers::PropertyData<bool>(146, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
        // property 'isAllowMeteredFeedUpdatesImmutable'
        QtMocHelpers::PropertyData<bool>(147, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAllowMeteredFeedUpdatesValue'
        QtMocHelpers::PropertyData<bool>(148, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'allowMeteredEpisodeDownloads'
        QtMocHelpers::PropertyData<bool>(149, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 31),
        // property 'isAllowMeteredEpisodeDownloadsImmutable'
        QtMocHelpers::PropertyData<bool>(150, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAllowMeteredEpisodeDownloadsValue'
        QtMocHelpers::PropertyData<bool>(151, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'allowMeteredImageDownloads'
        QtMocHelpers::PropertyData<bool>(152, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'isAllowMeteredImageDownloadsImmutable'
        QtMocHelpers::PropertyData<bool>(153, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAllowMeteredImageDownloadsValue'
        QtMocHelpers::PropertyData<bool>(154, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'allowMeteredStreaming'
        QtMocHelpers::PropertyData<bool>(155, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'isAllowMeteredStreamingImmutable'
        QtMocHelpers::PropertyData<bool>(156, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAllowMeteredStreamingValue'
        QtMocHelpers::PropertyData<bool>(157, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sleepTimerValue'
        QtMocHelpers::PropertyData<int>(158, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'isSleepTimerValueImmutable'
        QtMocHelpers::PropertyData<bool>(159, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSleepTimerValueValue'
        QtMocHelpers::PropertyData<int>(160, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sleepTimerUnits'
        QtMocHelpers::PropertyData<int>(161, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 35),
        // property 'isSleepTimerUnitsImmutable'
        QtMocHelpers::PropertyData<bool>(162, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSleepTimerUnitsValue'
        QtMocHelpers::PropertyData<int>(163, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'syncEnabled'
        QtMocHelpers::PropertyData<bool>(164, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 36),
        // property 'isSyncEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(165, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSyncEnabledValue'
        QtMocHelpers::PropertyData<bool>(166, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'syncWhenUpdatingFeeds'
        QtMocHelpers::PropertyData<bool>(167, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37),
        // property 'isSyncWhenUpdatingFeedsImmutable'
        QtMocHelpers::PropertyData<bool>(168, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSyncWhenUpdatingFeedsValue'
        QtMocHelpers::PropertyData<bool>(169, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'syncWhenPlayerstateChanges'
        QtMocHelpers::PropertyData<bool>(170, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 38),
        // property 'isSyncWhenPlayerstateChangesImmutable'
        QtMocHelpers::PropertyData<bool>(171, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSyncWhenPlayerstateChangesValue'
        QtMocHelpers::PropertyData<bool>(172, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'syncProvider'
        QtMocHelpers::PropertyData<int>(173, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 39),
        // property 'isSyncProviderImmutable'
        QtMocHelpers::PropertyData<bool>(174, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSyncProviderValue'
        QtMocHelpers::PropertyData<int>(175, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'syncHostname'
        QtMocHelpers::PropertyData<QString>(176, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 40),
        // property 'isSyncHostnameImmutable'
        QtMocHelpers::PropertyData<bool>(177, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'syncUsername'
        QtMocHelpers::PropertyData<QString>(178, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 41),
        // property 'isSyncUsernameImmutable'
        QtMocHelpers::PropertyData<bool>(179, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'syncDevice'
        QtMocHelpers::PropertyData<QString>(180, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 42),
        // property 'isSyncDeviceImmutable'
        QtMocHelpers::PropertyData<bool>(181, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'syncDeviceName'
        QtMocHelpers::PropertyData<QString>(182, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 43),
        // property 'isSyncDeviceNameImmutable'
        QtMocHelpers::PropertyData<bool>(183, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyType'
        QtMocHelpers::PropertyData<int>(184, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 44),
        // property 'isProxyTypeImmutable'
        QtMocHelpers::PropertyData<bool>(185, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyHost'
        QtMocHelpers::PropertyData<QString>(186, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 45),
        // property 'isProxyHostImmutable'
        QtMocHelpers::PropertyData<bool>(187, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProxyHostValue'
        QtMocHelpers::PropertyData<QString>(188, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyPort'
        QtMocHelpers::PropertyData<int>(189, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 46),
        // property 'isProxyPortImmutable'
        QtMocHelpers::PropertyData<bool>(190, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProxyPortValue'
        QtMocHelpers::PropertyData<int>(191, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyUser'
        QtMocHelpers::PropertyData<QString>(192, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 47),
        // property 'isProxyUserImmutable'
        QtMocHelpers::PropertyData<bool>(193, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyPassword'
        QtMocHelpers::PropertyData<QString>(194, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 48),
        // property 'isProxyPasswordImmutable'
        QtMocHelpers::PropertyData<bool>(195, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SettingsManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SettingsManager::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SettingsManagerE_t>.metaTypes,
    nullptr
} };

void SettingsManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->prioritizeStreamingChanged(); break;
        case 1: _t->continuePlayingNextEntryChanged(); break;
        case 2: _t->adjustTimeLeftChanged(); break;
        case 3: _t->refreshOnStartupChanged(); break;
        case 4: _t->doFullUpdateChanged(); break;
        case 5: _t->autoQueueChanged(); break;
        case 6: _t->autoDownloadChanged(); break;
        case 7: _t->autoFeedUpdateIntervalChanged(); break;
        case 8: _t->autoDeleteOnPlayedChanged(); break;
        case 9: _t->markAsPlayedBeforeEndChanged(); break;
        case 10: _t->resetPositionOnPlayedChanged(); break;
        case 11: _t->markUnreadOnNewFeedChanged(); break;
        case 12: _t->markUnreadOnNewFeedCustomAmountChanged(); break;
        case 13: _t->toggleRemainingTimeChanged(); break;
        case 14: _t->articleFontSizeChanged(); break;
        case 15: _t->StoragePathChanged(); break;
        case 16: _t->alwaysShowFeedTitlesChanged(); break;
        case 17: _t->showEpisodeImageChanged(); break;
        case 18: _t->showPodcastTitleChanged(); break;
        case 19: _t->showTrayIconChanged(); break;
        case 20: _t->trayIconTypeChanged(); break;
        case 21: _t->minimizeToTrayChanged(); break;
        case 22: _t->articleFontUseSystemChanged(); break;
        case 23: _t->interfaceModeChanged(); break;
        case 24: _t->mediabackendChanged(); break;
        case 25: _t->playbackRatesChanged(); break;
        case 26: _t->skipForwardChanged(); break;
        case 27: _t->skipBackwardChanged(); break;
        case 28: _t->maximumParallelEpisodeDownloadsChanged(); break;
        case 29: _t->checkNetworkStatusChanged(); break;
        case 30: _t->allowMeteredFeedUpdatesChanged(); break;
        case 31: _t->allowMeteredEpisodeDownloadsChanged(); break;
        case 32: _t->allowMeteredImageDownloadsChanged(); break;
        case 33: _t->allowMeteredStreamingChanged(); break;
        case 34: _t->sleepTimerValueChanged(); break;
        case 35: _t->sleepTimerUnitsChanged(); break;
        case 36: _t->syncEnabledChanged(); break;
        case 37: _t->syncWhenUpdatingFeedsChanged(); break;
        case 38: _t->syncWhenPlayerstateChangesChanged(); break;
        case 39: _t->syncProviderChanged(); break;
        case 40: _t->syncHostnameChanged(); break;
        case 41: _t->syncUsernameChanged(); break;
        case 42: _t->syncDeviceChanged(); break;
        case 43: _t->syncDeviceNameChanged(); break;
        case 44: _t->ProxyTypeChanged(); break;
        case 45: _t->ProxyHostChanged(); break;
        case 46: _t->ProxyPortChanged(); break;
        case 47: _t->ProxyUserChanged(); break;
        case 48: _t->ProxyPasswordChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::prioritizeStreamingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::continuePlayingNextEntryChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::adjustTimeLeftChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::refreshOnStartupChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::doFullUpdateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::autoQueueChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::autoDownloadChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::autoFeedUpdateIntervalChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::autoDeleteOnPlayedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::markAsPlayedBeforeEndChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::resetPositionOnPlayedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::markUnreadOnNewFeedChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::markUnreadOnNewFeedCustomAmountChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::toggleRemainingTimeChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::articleFontSizeChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::StoragePathChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::alwaysShowFeedTitlesChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::showEpisodeImageChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::showPodcastTitleChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::showTrayIconChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::trayIconTypeChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::minimizeToTrayChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::articleFontUseSystemChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::interfaceModeChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::mediabackendChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::playbackRatesChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::skipForwardChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::skipBackwardChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::maximumParallelEpisodeDownloadsChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::checkNetworkStatusChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::allowMeteredFeedUpdatesChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::allowMeteredEpisodeDownloadsChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::allowMeteredImageDownloadsChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::allowMeteredStreamingChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::sleepTimerValueChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::sleepTimerUnitsChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::syncEnabledChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::syncWhenUpdatingFeedsChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::syncWhenPlayerstateChangesChanged, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::syncProviderChanged, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::syncHostnameChanged, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::syncUsernameChanged, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::syncDeviceChanged, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::syncDeviceNameChanged, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::ProxyTypeChanged, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::ProxyHostChanged, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::ProxyPortChanged, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::ProxyUserChanged, 47))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsManager::*)()>(_a, &SettingsManager::ProxyPasswordChanged, 48))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 76:
        case 74:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->prioritizeStreaming(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isPrioritizeStreamingImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultPrioritizeStreamingValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->continuePlayingNextEntry(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isContinuePlayingNextEntryImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultContinuePlayingNextEntryValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->adjustTimeLeft(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isAdjustTimeLeftImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultAdjustTimeLeftValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->refreshOnStartup(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isRefreshOnStartupImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultRefreshOnStartupValue(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->doFullUpdate(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isDoFullUpdateImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->defaultDoFullUpdateValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->autoQueue(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isAutoQueueImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultAutoQueueValue(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->autoDownload(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isAutoDownloadImmutable(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->defaultAutoDownloadValue(); break;
        case 21: *reinterpret_cast<int*>(_v) = _t->autoFeedUpdateInterval(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isAutoFeedUpdateIntervalImmutable(); break;
        case 23: *reinterpret_cast<int*>(_v) = _t->defaultAutoFeedUpdateIntervalValue(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->autoDeleteOnPlayed(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isAutoDeleteOnPlayedImmutable(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->defaultAutoDeleteOnPlayedValue(); break;
        case 27: *reinterpret_cast<int*>(_v) = _t->markAsPlayedBeforeEnd(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isMarkAsPlayedBeforeEndImmutable(); break;
        case 29: *reinterpret_cast<int*>(_v) = _t->defaultMarkAsPlayedBeforeEndValue(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->resetPositionOnPlayed(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isResetPositionOnPlayedImmutable(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->defaultResetPositionOnPlayedValue(); break;
        case 33: *reinterpret_cast<int*>(_v) = _t->markUnreadOnNewFeed(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isMarkUnreadOnNewFeedImmutable(); break;
        case 35: *reinterpret_cast<int*>(_v) = _t->defaultMarkUnreadOnNewFeedValue(); break;
        case 36: *reinterpret_cast<int*>(_v) = _t->markUnreadOnNewFeedCustomAmount(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isMarkUnreadOnNewFeedCustomAmountImmutable(); break;
        case 38: *reinterpret_cast<int*>(_v) = _t->defaultMarkUnreadOnNewFeedCustomAmountValue(); break;
        case 39: *reinterpret_cast<bool*>(_v) = _t->toggleRemainingTime(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isToggleRemainingTimeImmutable(); break;
        case 41: *reinterpret_cast<bool*>(_v) = _t->defaultToggleRemainingTimeValue(); break;
        case 42: *reinterpret_cast<int*>(_v) = _t->articleFontSize(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isArticleFontSizeImmutable(); break;
        case 44: *reinterpret_cast<int*>(_v) = _t->defaultArticleFontSizeValue(); break;
        case 45: *reinterpret_cast<QUrl*>(_v) = _t->storagePath(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isStoragePathImmutable(); break;
        case 47: *reinterpret_cast<bool*>(_v) = _t->alwaysShowFeedTitles(); break;
        case 48: *reinterpret_cast<bool*>(_v) = _t->isAlwaysShowFeedTitlesImmutable(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->defaultAlwaysShowFeedTitlesValue(); break;
        case 50: *reinterpret_cast<bool*>(_v) = _t->showEpisodeImage(); break;
        case 51: *reinterpret_cast<bool*>(_v) = _t->isShowEpisodeImageImmutable(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->defaultShowEpisodeImageValue(); break;
        case 53: *reinterpret_cast<bool*>(_v) = _t->showPodcastTitle(); break;
        case 54: *reinterpret_cast<bool*>(_v) = _t->isShowPodcastTitleImmutable(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->defaultShowPodcastTitleValue(); break;
        case 56: *reinterpret_cast<bool*>(_v) = _t->showTrayIcon(); break;
        case 57: *reinterpret_cast<bool*>(_v) = _t->isShowTrayIconImmutable(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->defaultShowTrayIconValue(); break;
        case 59: *reinterpret_cast<int*>(_v) = _t->trayIconType(); break;
        case 60: *reinterpret_cast<bool*>(_v) = _t->isTrayIconTypeImmutable(); break;
        case 61: *reinterpret_cast<int*>(_v) = _t->defaultTrayIconTypeValue(); break;
        case 62: *reinterpret_cast<bool*>(_v) = _t->minimizeToTray(); break;
        case 63: *reinterpret_cast<bool*>(_v) = _t->isMinimizeToTrayImmutable(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->defaultMinimizeToTrayValue(); break;
        case 65: *reinterpret_cast<bool*>(_v) = _t->articleFontUseSystem(); break;
        case 66: *reinterpret_cast<bool*>(_v) = _t->isArticleFontUseSystemImmutable(); break;
        case 67: *reinterpret_cast<bool*>(_v) = _t->defaultArticleFontUseSystemValue(); break;
        case 68: *reinterpret_cast<int*>(_v) = _t->interfaceMode(); break;
        case 69: *reinterpret_cast<bool*>(_v) = _t->isInterfaceModeImmutable(); break;
        case 70: *reinterpret_cast<int*>(_v) = _t->defaultInterfaceModeValue(); break;
        case 71: *reinterpret_cast<int*>(_v) = _t->mediabackend(); break;
        case 72: *reinterpret_cast<bool*>(_v) = _t->isMediabackendImmutable(); break;
        case 73: *reinterpret_cast<int*>(_v) = _t->defaultMediabackendValue(); break;
        case 74: *reinterpret_cast<QList<int>*>(_v) = _t->playbackRates(); break;
        case 75: *reinterpret_cast<bool*>(_v) = _t->isPlaybackRatesImmutable(); break;
        case 76: *reinterpret_cast<QList<int>*>(_v) = _t->defaultPlaybackRatesValue(); break;
        case 77: *reinterpret_cast<uint*>(_v) = _t->skipForward(); break;
        case 78: *reinterpret_cast<bool*>(_v) = _t->isSkipForwardImmutable(); break;
        case 79: *reinterpret_cast<uint*>(_v) = _t->defaultSkipForwardValue(); break;
        case 80: *reinterpret_cast<uint*>(_v) = _t->skipBackward(); break;
        case 81: *reinterpret_cast<bool*>(_v) = _t->isSkipBackwardImmutable(); break;
        case 82: *reinterpret_cast<uint*>(_v) = _t->defaultSkipBackwardValue(); break;
        case 83: *reinterpret_cast<int*>(_v) = _t->maximumParallelEpisodeDownloads(); break;
        case 84: *reinterpret_cast<bool*>(_v) = _t->isMaximumParallelEpisodeDownloadsImmutable(); break;
        case 85: *reinterpret_cast<int*>(_v) = _t->defaultMaximumParallelEpisodeDownloadsValue(); break;
        case 86: *reinterpret_cast<bool*>(_v) = _t->checkNetworkStatus(); break;
        case 87: *reinterpret_cast<bool*>(_v) = _t->isCheckNetworkStatusImmutable(); break;
        case 88: *reinterpret_cast<bool*>(_v) = _t->defaultCheckNetworkStatusValue(); break;
        case 89: *reinterpret_cast<bool*>(_v) = _t->allowMeteredFeedUpdates(); break;
        case 90: *reinterpret_cast<bool*>(_v) = _t->isAllowMeteredFeedUpdatesImmutable(); break;
        case 91: *reinterpret_cast<bool*>(_v) = _t->defaultAllowMeteredFeedUpdatesValue(); break;
        case 92: *reinterpret_cast<bool*>(_v) = _t->allowMeteredEpisodeDownloads(); break;
        case 93: *reinterpret_cast<bool*>(_v) = _t->isAllowMeteredEpisodeDownloadsImmutable(); break;
        case 94: *reinterpret_cast<bool*>(_v) = _t->defaultAllowMeteredEpisodeDownloadsValue(); break;
        case 95: *reinterpret_cast<bool*>(_v) = _t->allowMeteredImageDownloads(); break;
        case 96: *reinterpret_cast<bool*>(_v) = _t->isAllowMeteredImageDownloadsImmutable(); break;
        case 97: *reinterpret_cast<bool*>(_v) = _t->defaultAllowMeteredImageDownloadsValue(); break;
        case 98: *reinterpret_cast<bool*>(_v) = _t->allowMeteredStreaming(); break;
        case 99: *reinterpret_cast<bool*>(_v) = _t->isAllowMeteredStreamingImmutable(); break;
        case 100: *reinterpret_cast<bool*>(_v) = _t->defaultAllowMeteredStreamingValue(); break;
        case 101: *reinterpret_cast<int*>(_v) = _t->sleepTimerValue(); break;
        case 102: *reinterpret_cast<bool*>(_v) = _t->isSleepTimerValueImmutable(); break;
        case 103: *reinterpret_cast<int*>(_v) = _t->defaultSleepTimerValueValue(); break;
        case 104: *reinterpret_cast<int*>(_v) = _t->sleepTimerUnits(); break;
        case 105: *reinterpret_cast<bool*>(_v) = _t->isSleepTimerUnitsImmutable(); break;
        case 106: *reinterpret_cast<int*>(_v) = _t->defaultSleepTimerUnitsValue(); break;
        case 107: *reinterpret_cast<bool*>(_v) = _t->syncEnabled(); break;
        case 108: *reinterpret_cast<bool*>(_v) = _t->isSyncEnabledImmutable(); break;
        case 109: *reinterpret_cast<bool*>(_v) = _t->defaultSyncEnabledValue(); break;
        case 110: *reinterpret_cast<bool*>(_v) = _t->syncWhenUpdatingFeeds(); break;
        case 111: *reinterpret_cast<bool*>(_v) = _t->isSyncWhenUpdatingFeedsImmutable(); break;
        case 112: *reinterpret_cast<bool*>(_v) = _t->defaultSyncWhenUpdatingFeedsValue(); break;
        case 113: *reinterpret_cast<bool*>(_v) = _t->syncWhenPlayerstateChanges(); break;
        case 114: *reinterpret_cast<bool*>(_v) = _t->isSyncWhenPlayerstateChangesImmutable(); break;
        case 115: *reinterpret_cast<bool*>(_v) = _t->defaultSyncWhenPlayerstateChangesValue(); break;
        case 116: *reinterpret_cast<int*>(_v) = _t->syncProvider(); break;
        case 117: *reinterpret_cast<bool*>(_v) = _t->isSyncProviderImmutable(); break;
        case 118: *reinterpret_cast<int*>(_v) = _t->defaultSyncProviderValue(); break;
        case 119: *reinterpret_cast<QString*>(_v) = _t->syncHostname(); break;
        case 120: *reinterpret_cast<bool*>(_v) = _t->isSyncHostnameImmutable(); break;
        case 121: *reinterpret_cast<QString*>(_v) = _t->syncUsername(); break;
        case 122: *reinterpret_cast<bool*>(_v) = _t->isSyncUsernameImmutable(); break;
        case 123: *reinterpret_cast<QString*>(_v) = _t->syncDevice(); break;
        case 124: *reinterpret_cast<bool*>(_v) = _t->isSyncDeviceImmutable(); break;
        case 125: *reinterpret_cast<QString*>(_v) = _t->syncDeviceName(); break;
        case 126: *reinterpret_cast<bool*>(_v) = _t->isSyncDeviceNameImmutable(); break;
        case 127: *reinterpret_cast<int*>(_v) = _t->proxyType(); break;
        case 128: *reinterpret_cast<bool*>(_v) = _t->isProxyTypeImmutable(); break;
        case 129: *reinterpret_cast<QString*>(_v) = _t->proxyHost(); break;
        case 130: *reinterpret_cast<bool*>(_v) = _t->isProxyHostImmutable(); break;
        case 131: *reinterpret_cast<QString*>(_v) = _t->defaultProxyHostValue(); break;
        case 132: *reinterpret_cast<int*>(_v) = _t->proxyPort(); break;
        case 133: *reinterpret_cast<bool*>(_v) = _t->isProxyPortImmutable(); break;
        case 134: *reinterpret_cast<int*>(_v) = _t->defaultProxyPortValue(); break;
        case 135: *reinterpret_cast<QString*>(_v) = _t->proxyUser(); break;
        case 136: *reinterpret_cast<bool*>(_v) = _t->isProxyUserImmutable(); break;
        case 137: *reinterpret_cast<QString*>(_v) = _t->proxyPassword(); break;
        case 138: *reinterpret_cast<bool*>(_v) = _t->isProxyPasswordImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPrioritizeStreaming(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setContinuePlayingNextEntry(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setAdjustTimeLeft(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setRefreshOnStartup(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setDoFullUpdate(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setAutoQueue(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setAutoDownload(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setAutoFeedUpdateInterval(*reinterpret_cast<int*>(_v)); break;
        case 24: _t->setAutoDeleteOnPlayed(*reinterpret_cast<int*>(_v)); break;
        case 27: _t->setMarkAsPlayedBeforeEnd(*reinterpret_cast<int*>(_v)); break;
        case 30: _t->setResetPositionOnPlayed(*reinterpret_cast<bool*>(_v)); break;
        case 33: _t->setMarkUnreadOnNewFeed(*reinterpret_cast<int*>(_v)); break;
        case 36: _t->setMarkUnreadOnNewFeedCustomAmount(*reinterpret_cast<int*>(_v)); break;
        case 39: _t->setToggleRemainingTime(*reinterpret_cast<bool*>(_v)); break;
        case 42: _t->setArticleFontSize(*reinterpret_cast<int*>(_v)); break;
        case 45: _t->setStoragePath(*reinterpret_cast<QUrl*>(_v)); break;
        case 47: _t->setAlwaysShowFeedTitles(*reinterpret_cast<bool*>(_v)); break;
        case 50: _t->setShowEpisodeImage(*reinterpret_cast<bool*>(_v)); break;
        case 53: _t->setShowPodcastTitle(*reinterpret_cast<bool*>(_v)); break;
        case 56: _t->setShowTrayIcon(*reinterpret_cast<bool*>(_v)); break;
        case 59: _t->setTrayIconType(*reinterpret_cast<int*>(_v)); break;
        case 62: _t->setMinimizeToTray(*reinterpret_cast<bool*>(_v)); break;
        case 65: _t->setArticleFontUseSystem(*reinterpret_cast<bool*>(_v)); break;
        case 68: _t->setInterfaceMode(*reinterpret_cast<int*>(_v)); break;
        case 71: _t->setMediabackend(*reinterpret_cast<int*>(_v)); break;
        case 74: _t->setPlaybackRates(*reinterpret_cast<QList<int>*>(_v)); break;
        case 77: _t->setSkipForward(*reinterpret_cast<uint*>(_v)); break;
        case 80: _t->setSkipBackward(*reinterpret_cast<uint*>(_v)); break;
        case 83: _t->setMaximumParallelEpisodeDownloads(*reinterpret_cast<int*>(_v)); break;
        case 86: _t->setCheckNetworkStatus(*reinterpret_cast<bool*>(_v)); break;
        case 89: _t->setAllowMeteredFeedUpdates(*reinterpret_cast<bool*>(_v)); break;
        case 92: _t->setAllowMeteredEpisodeDownloads(*reinterpret_cast<bool*>(_v)); break;
        case 95: _t->setAllowMeteredImageDownloads(*reinterpret_cast<bool*>(_v)); break;
        case 98: _t->setAllowMeteredStreaming(*reinterpret_cast<bool*>(_v)); break;
        case 101: _t->setSleepTimerValue(*reinterpret_cast<int*>(_v)); break;
        case 104: _t->setSleepTimerUnits(*reinterpret_cast<int*>(_v)); break;
        case 107: _t->setSyncEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 110: _t->setSyncWhenUpdatingFeeds(*reinterpret_cast<bool*>(_v)); break;
        case 113: _t->setSyncWhenPlayerstateChanges(*reinterpret_cast<bool*>(_v)); break;
        case 116: _t->setSyncProvider(*reinterpret_cast<int*>(_v)); break;
        case 119: _t->setSyncHostname(*reinterpret_cast<QString*>(_v)); break;
        case 121: _t->setSyncUsername(*reinterpret_cast<QString*>(_v)); break;
        case 123: _t->setSyncDevice(*reinterpret_cast<QString*>(_v)); break;
        case 125: _t->setSyncDeviceName(*reinterpret_cast<QString*>(_v)); break;
        case 127: _t->setProxyType(*reinterpret_cast<int*>(_v)); break;
        case 129: _t->setProxyHost(*reinterpret_cast<QString*>(_v)); break;
        case 132: _t->setProxyPort(*reinterpret_cast<int*>(_v)); break;
        case 135: _t->setProxyUser(*reinterpret_cast<QString*>(_v)); break;
        case 137: _t->setProxyPassword(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SettingsManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SettingsManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsManagerE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int SettingsManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 49)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 49;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 49)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 49;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 139;
    }
    return _id;
}

// SIGNAL 0
void SettingsManager::prioritizeStreamingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SettingsManager::continuePlayingNextEntryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SettingsManager::adjustTimeLeftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SettingsManager::refreshOnStartupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SettingsManager::doFullUpdateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SettingsManager::autoQueueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void SettingsManager::autoDownloadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void SettingsManager::autoFeedUpdateIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void SettingsManager::autoDeleteOnPlayedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void SettingsManager::markAsPlayedBeforeEndChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void SettingsManager::resetPositionOnPlayedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void SettingsManager::markUnreadOnNewFeedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void SettingsManager::markUnreadOnNewFeedCustomAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void SettingsManager::toggleRemainingTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void SettingsManager::articleFontSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void SettingsManager::StoragePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void SettingsManager::alwaysShowFeedTitlesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void SettingsManager::showEpisodeImageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void SettingsManager::showPodcastTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void SettingsManager::showTrayIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void SettingsManager::trayIconTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void SettingsManager::minimizeToTrayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void SettingsManager::articleFontUseSystemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void SettingsManager::interfaceModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void SettingsManager::mediabackendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void SettingsManager::playbackRatesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void SettingsManager::skipForwardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void SettingsManager::skipBackwardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void SettingsManager::maximumParallelEpisodeDownloadsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void SettingsManager::checkNetworkStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void SettingsManager::allowMeteredFeedUpdatesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void SettingsManager::allowMeteredEpisodeDownloadsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void SettingsManager::allowMeteredImageDownloadsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void SettingsManager::allowMeteredStreamingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void SettingsManager::sleepTimerValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void SettingsManager::sleepTimerUnitsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void SettingsManager::syncEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void SettingsManager::syncWhenUpdatingFeedsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void SettingsManager::syncWhenPlayerstateChangesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void SettingsManager::syncProviderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}

// SIGNAL 40
void SettingsManager::syncHostnameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 40, nullptr);
}

// SIGNAL 41
void SettingsManager::syncUsernameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 41, nullptr);
}

// SIGNAL 42
void SettingsManager::syncDeviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 42, nullptr);
}

// SIGNAL 43
void SettingsManager::syncDeviceNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 43, nullptr);
}

// SIGNAL 44
void SettingsManager::ProxyTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 44, nullptr);
}

// SIGNAL 45
void SettingsManager::ProxyHostChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 45, nullptr);
}

// SIGNAL 46
void SettingsManager::ProxyPortChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 46, nullptr);
}

// SIGNAL 47
void SettingsManager::ProxyUserChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 47, nullptr);
}

// SIGNAL 48
void SettingsManager::ProxyPasswordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 48, nullptr);
}
QT_WARNING_POP
