// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "kmediasessionlogging.h"


Q_LOGGING_CATEGORY(KMediaSessionLog, "org.kde.kmediasession.kmediasession", QtInfoMsg)

