/****************************************************************************
** Meta object code from reading C++ file 'syncutils.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/sync/syncutils.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'syncutils.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9SyncUtils6DeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto SyncUtils::Device::qt_create_metaobjectdata<qt_meta_tag_ZN9SyncUtils6DeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SyncUtils::Device",
        "QML.Element",
        "device",
        "caption",
        "id",
        "type",
        "subscriptions"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'caption'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'id'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'type'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'subscriptions'
        QtMocHelpers::PropertyData<int>(6, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Device, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SyncUtils::Device::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9SyncUtils6DeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9SyncUtils6DeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9SyncUtils6DeviceE_t>.metaTypes,
    nullptr
} };

void SyncUtils::Device::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Device *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->caption; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->id; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->type; break;
        case 3: *reinterpret_cast<int*>(_v) = _t->subscriptions; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->caption, *reinterpret_cast<QString*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->id, *reinterpret_cast<QString*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->type, *reinterpret_cast<QString*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->subscriptions, *reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN9SyncUtilsE_t {};
} // unnamed namespace

template <> constexpr inline auto SyncUtils::qt_create_metaobjectdata<qt_meta_tag_ZN9SyncUtilsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SyncUtils",
        "QML.Element",
        "auto",
        "Provider",
        "GPodderNet",
        "GPodderNextcloud",
        "SyncStatus",
        "NoSync",
        "RegularSync",
        "ForceSync",
        "UploadOnlySync",
        "PushAllSync"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Provider'
        QtMocHelpers::EnumData<Provider>(3, 3, QMC::EnumFlags{}).add({
            {    4, Provider::GPodderNet },
            {    5, Provider::GPodderNextcloud },
        }),
        // enum 'SyncStatus'
        QtMocHelpers::EnumData<SyncStatus>(6, 6, QMC::EnumFlags{}).add({
            {    7, SyncStatus::NoSync },
            {    8, SyncStatus::RegularSync },
            {    9, SyncStatus::ForceSync },
            {   10, SyncStatus::UploadOnlySync },
            {   11, SyncStatus::PushAllSync },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN9SyncUtilsE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN9SyncUtilsE =
    SyncUtils::qt_create_metaobjectdata<qt_meta_tag_ZN9SyncUtilsE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN9SyncUtilsE =
    qt_staticMetaObjectContent_ZN9SyncUtilsE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN9SyncUtilsE =
    qt_staticMetaObjectContent_ZN9SyncUtilsE.relocatingData;

Q_CONSTINIT const QMetaObject SyncUtils::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN9SyncUtilsE.stringdata,
    qt_staticMetaObjectStaticContent_ZN9SyncUtilsE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN9SyncUtilsE.metaTypes,
    nullptr
} };

QT_WARNING_POP
