/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<abstractepisodemodel.h>)
#  include <abstractepisodemodel.h>
#endif
#if __has_include(<abstractepisodeproxymodel.h>)
#  include <abstractepisodeproxymodel.h>
#endif
#if __has_include(<audiomanager.h>)
#  include <audiomanager.h>
#endif
#if __has_include(<chapter.h>)
#  include <chapter.h>
#endif
#if __has_include(<chaptermodel.h>)
#  include <chaptermodel.h>
#endif
#if __has_include(<colorschemer.h>)
#  include <colorschemer.h>
#endif
#if __has_include(<database.h>)
#  include <database.h>
#endif
#if __has_include(<datamanager.h>)
#  include <datamanager.h>
#endif
#if __has_include(<datatypes.h>)
#  include <datatypes.h>
#endif
#if __has_include(<downloadmodel.h>)
#  include <downloadmodel.h>
#endif
#if __has_include(<enclosure.h>)
#  include <enclosure.h>
#endif
#if __has_include(<entriesproxymodel.h>)
#  include <entriesproxymodel.h>
#endif
#if __has_include(<entry.h>)
#  include <entry.h>
#endif
#if __has_include(<episodeproxymodel.h>)
#  include <episodeproxymodel.h>
#endif
#if __has_include(<error.h>)
#  include <error.h>
#endif
#if __has_include(<errorlogmodel.h>)
#  include <errorlogmodel.h>
#endif
#if __has_include(<feed.h>)
#  include <feed.h>
#endif
#if __has_include(<feedsmodel.h>)
#  include <feedsmodel.h>
#endif
#if __has_include(<feedsproxymodel.h>)
#  include <feedsproxymodel.h>
#endif
#if __has_include(<fetcher.h>)
#  include <fetcher.h>
#endif
#if __has_include(<networkconnectionmanager.h>)
#  include <networkconnectionmanager.h>
#endif
#if __has_include(<podcastsearchmodel.h>)
#  include <podcastsearchmodel.h>
#endif
#if __has_include(<queuemodel.h>)
#  include <queuemodel.h>
#endif
#if __has_include(<settingsmanager.h>)
#  include <settingsmanager.h>
#endif
#if __has_include(<storagemanager.h>)
#  include <storagemanager.h>
#endif
#if __has_include(<sync.h>)
#  include <sync.h>
#endif
#if __has_include(<syncutils.h>)
#  include <syncutils.h>
#endif
#if __has_include(<systrayicon.h>)
#  include <systrayicon.h>
#endif
#if __has_include(<windowutils.h>)
#  include <windowutils.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kasts()
{
    qmlRegisterModule("org.kde.kasts", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AbstractEpisodeModel>("org.kde.kasts", 254);
    qmlRegisterEnum<AbstractEpisodeModel::Roles>("AbstractEpisodeModel::Roles");
    qmlRegisterTypesAndRevisions<AbstractEpisodeProxyModel>("org.kde.kasts", 254);
    qmlRegisterEnum<AbstractEpisodeProxyModel::FilterType>("AbstractEpisodeProxyModel::FilterType");
    qmlRegisterEnum<AbstractEpisodeProxyModel::SearchFlag>("AbstractEpisodeProxyModel::SearchFlag");
    qmlRegisterEnum<AbstractEpisodeProxyModel::SearchFlags>("AbstractEpisodeProxyModel::SearchFlags");
    qmlRegisterEnum<AbstractEpisodeProxyModel::SearchFlag>("AbstractEpisodeProxyModel::SearchFlag");
    qmlRegisterEnum<AbstractEpisodeProxyModel::SortType>("AbstractEpisodeProxyModel::SortType");
    qmlRegisterTypesAndRevisions<AudioManager>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<Chapter>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<ChapterModel>("org.kde.kasts", 254);
    qmlRegisterEnum<ChapterModel::RoleNames>("ChapterModel::RoleNames");
    qmlRegisterTypesAndRevisions<ColorSchemer>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<DataManager>("org.kde.kasts", 254);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &DataTypes::staticMetaObject;},
            "DataTypes");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&DataTypes::staticMetaObject, "org.kde.kasts", 254, nullptr, &DataTypes::staticMetaObject, nullptr);
    qmlRegisterEnum<DataTypes::RecordState>("DataTypes::RecordState");
    qmlRegisterTypesAndRevisions<Database>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<DownloadModel>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<Enclosure>("org.kde.kasts", 254);
    qmlRegisterEnum<Enclosure::Status>("Enclosure::Status");
    qmlRegisterTypesAndRevisions<EntriesProxyModel>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<Entry>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<EpisodeProxyModel>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<Error>("org.kde.kasts", 254);
    qmlRegisterEnum<Error::Type>("Error::Type");
    qmlRegisterTypesAndRevisions<ErrorLogModel>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<Feed>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<FeedsModel>("org.kde.kasts", 254);
    qmlRegisterEnum<FeedsModel::Roles>("FeedsModel::Roles");
    qmlRegisterTypesAndRevisions<FeedsProxyModel>("org.kde.kasts", 254);
    qmlRegisterEnum<FeedsProxyModel::SortType>("FeedsProxyModel::SortType");
    qmlRegisterTypesAndRevisions<Fetcher>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<NetworkConnectionManager>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<PodcastSearchModel>("org.kde.kasts", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<QueueModel>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<SettingsManager>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<StorageManager>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<Sync>("org.kde.kasts", 254);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &SyncUtils::staticMetaObject;},
            "SyncUtils");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&SyncUtils::staticMetaObject, "org.kde.kasts", 254, nullptr, &SyncUtils::staticMetaObject, nullptr);
    qmlRegisterEnum<SyncUtils::Provider>("SyncUtils::Provider");
    qmlRegisterEnum<SyncUtils::SyncStatus>("SyncUtils::SyncStatus");
    qmlRegisterTypesAndRevisions<SyncUtils::Device>("org.kde.kasts", 254);
    qmlRegisterTypesAndRevisions<SystrayIcon>("org.kde.kasts", 254);
    qmlRegisterEnum<SystrayIcon::IconColor>("SystrayIcon::IconColor");
    qmlRegisterTypesAndRevisions<WindowUtils>("org.kde.kasts", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kasts", 254, 254);
}

static const QQmlModuleRegistration orgkdekastsRegistration("org.kde.kasts", qml_register_types_org_kde_kasts);
