/****************************************************************************
** Meta object code from reading C++ file 'feedsproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/models/feedsproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'feedsproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15FeedsProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto FeedsProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN15FeedsProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FeedsProxyModel",
        "QML.Element",
        "auto",
        "searchFilterChanged",
        "",
        "sortTypeChanged",
        "getSortName",
        "SortType",
        "type",
        "getSortIconName",
        "createSelection",
        "QItemSelection",
        "rowa",
        "rowb",
        "searchFilter",
        "sortType",
        "UnreadDescending",
        "UnreadAscending",
        "NewDescending",
        "NewAscending",
        "FavoriteDescending",
        "FavoriteAscending",
        "TitleAscending",
        "TitleDescending"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'searchFilterChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortTypeChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'getSortName'
        QtMocHelpers::MethodData<QString(enum SortType) const>(6, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'getSortIconName'
        QtMocHelpers::MethodData<QString(enum SortType) const>(9, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'createSelection'
        QtMocHelpers::MethodData<QItemSelection(int, int)>(10, 4, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Int, 12 }, { QMetaType::Int, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'searchFilter'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'sortType'
        QtMocHelpers::PropertyData<enum SortType>(15, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SortType'
        QtMocHelpers::EnumData<enum SortType>(7, 7, QMC::EnumFlags{}).add({
            {   16, SortType::UnreadDescending },
            {   17, SortType::UnreadAscending },
            {   18, SortType::NewDescending },
            {   19, SortType::NewAscending },
            {   20, SortType::FavoriteDescending },
            {   21, SortType::FavoriteAscending },
            {   22, SortType::TitleAscending },
            {   23, SortType::TitleDescending },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<FeedsProxyModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FeedsProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FeedsProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FeedsProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15FeedsProxyModelE_t>.metaTypes,
    nullptr
} };

void FeedsProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FeedsProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->searchFilterChanged(); break;
        case 1: _t->sortTypeChanged(); break;
        case 2: { QString _r = _t->getSortName((*reinterpret_cast<std::add_pointer_t<enum SortType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->getSortIconName((*reinterpret_cast<std::add_pointer_t<enum SortType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QItemSelection _r = _t->createSelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QItemSelection*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FeedsProxyModel::*)()>(_a, &FeedsProxyModel::searchFilterChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FeedsProxyModel::*)()>(_a, &FeedsProxyModel::sortTypeChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->searchFilter(); break;
        case 1: *reinterpret_cast<enum SortType*>(_v) = _t->sortType(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSearchFilter(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setSortType(*reinterpret_cast<enum SortType*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FeedsProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FeedsProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FeedsProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int FeedsProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void FeedsProxyModel::searchFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FeedsProxyModel::sortTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
