// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "storagemovejoblogging.h"


Q_LOGGING_CATEGORY(kastsStorageMoveJob, "org.kde.kasts.storagemovejob", QtInfoMsg)

