// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "powermanagementinterfacelogging.h"


Q_LOGGING_CATEGORY(KMediaSessionPowerManagementInterface, "org.kde.kmediasession.powermanagementinterface", QtInfoMsg)

