// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "storagemanagerlogging.h"


Q_LOGGING_CATEGORY(kastsStorageManager, "org.kde.kasts.storagemanager", QtInfoMsg)

