/****************************************************************************
** Meta object code from reading C++ file 'queuemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/models/queuemodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'queuemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10QueueModelE_t {};
} // unnamed namespace

template <> constexpr inline auto QueueModel::qt_create_metaobjectdata<qt_meta_tag_ZN10QueueModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QueueModel",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "timeLeftChanged",
        "",
        "queueEntriesAdded",
        "beginPos",
        "endPos",
        "QList<qint64>",
        "entryuids",
        "queueEntriesRemoved",
        "positions",
        "queueEntryMoved",
        "from",
        "to",
        "queueSorted",
        "updateInternalState",
        "getSortName",
        "AbstractEpisodeProxyModel::SortType",
        "type",
        "getSortIconName",
        "createSelection",
        "QItemSelection",
        "rowa",
        "rowb",
        "moveQueueItem",
        "sortQueue",
        "sortType",
        "timeLeft",
        "formattedTimeLeft"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'timeLeftChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'queueEntriesAdded'
        QtMocHelpers::SignalData<void(const qint64, const qint64, const QList<qint64> &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 8 }, { QMetaType::LongLong, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'queueEntriesRemoved'
        QtMocHelpers::SignalData<void(const QList<qint64> &, const QList<qint64> &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 13 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'queueEntryMoved'
        QtMocHelpers::SignalData<void(const int &, const int &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Signal 'queueSorted'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateInternalState'
        QtMocHelpers::SlotData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'getSortName'
        QtMocHelpers::MethodData<QString(AbstractEpisodeProxyModel::SortType)>(19, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Method 'getSortIconName'
        QtMocHelpers::MethodData<QString(AbstractEpisodeProxyModel::SortType)>(22, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Method 'createSelection'
        QtMocHelpers::MethodData<QItemSelection(int, int)>(23, 6, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::Int, 25 }, { QMetaType::Int, 26 },
        }}),
        // Method 'moveQueueItem'
        QtMocHelpers::MethodData<void(const qint64, const qint64)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 15 }, { QMetaType::LongLong, 16 },
        }}),
        // Method 'sortQueue'
        QtMocHelpers::MethodData<void(const AbstractEpisodeProxyModel::SortType)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'timeLeft'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'formattedTimeLeft'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QueueModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QueueModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractEpisodeModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QueueModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QueueModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10QueueModelE_t>.metaTypes,
    nullptr
} };

void QueueModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QueueModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->timeLeftChanged(); break;
        case 1: _t->queueEntriesAdded((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[3]))); break;
        case 2: _t->queueEntriesRemoved((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 3: _t->queueEntryMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->queueSorted(); break;
        case 5: _t->updateInternalState(); break;
        case 6: { QString _r = _t->getSortName((*reinterpret_cast<std::add_pointer_t<AbstractEpisodeProxyModel::SortType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->getSortIconName((*reinterpret_cast<std::add_pointer_t<AbstractEpisodeProxyModel::SortType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QItemSelection _r = _t->createSelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QItemSelection*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->moveQueueItem((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 10: _t->sortQueue((*reinterpret_cast<std::add_pointer_t<AbstractEpisodeProxyModel::SortType>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractEpisodeProxyModel::SortType >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractEpisodeProxyModel::SortType >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractEpisodeProxyModel::SortType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QueueModel::*)()>(_a, &QueueModel::timeLeftChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueModel::*)(const qint64 , const qint64 , const QList<qint64> & )>(_a, &QueueModel::queueEntriesAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueModel::*)(const QList<qint64> & , const QList<qint64> & )>(_a, &QueueModel::queueEntriesRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueModel::*)(const int & , const int & )>(_a, &QueueModel::queueEntryMoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueModel::*)()>(_a, &QueueModel::queueSorted, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->timeLeft(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->formattedTimeLeft(); break;
        default: break;
        }
    }
}

const QMetaObject *QueueModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QueueModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QueueModelE_t>.strings))
        return static_cast<void*>(this);
    return AbstractEpisodeModel::qt_metacast(_clname);
}

int QueueModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractEpisodeModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void QueueModel::timeLeftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QueueModel::queueEntriesAdded(const qint64 _t1, const qint64 _t2, const QList<qint64> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void QueueModel::queueEntriesRemoved(const QList<qint64> & _t1, const QList<qint64> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void QueueModel::queueEntryMoved(const int & _t1, const int & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void QueueModel::queueSorted()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
