/****************************************************************************
** Meta object code from reading C++ file 'datamanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/datamanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'datamanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11DataManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto DataManager::qt_create_metaobjectdata<qt_meta_tag_ZN11DataManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DataManager",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "feedAdded",
        "",
        "feeduid",
        "feedRemoved",
        "feedEntriesUpdated",
        "entryReadStatusChanged",
        "state",
        "QList<qint64>",
        "entryuids",
        "entryNewStatusChanged",
        "entryFavoriteStatusChanged",
        "entryQueueStatusChanged",
        "entryPlayPositionsChanged",
        "positions",
        "enclosureDurationsChanged",
        "durations",
        "enclosureSizesChanged",
        "sizes",
        "enclosureStatusesChanged",
        "QList<Enclosure::Status>",
        "statuses",
        "unreadEntryCountChanged",
        "newEntryCountChanged",
        "favoriteEntryCountChanged",
        "getFeed",
        "Feed*",
        "getEntry",
        "Entry*",
        "entryuid",
        "feedurl",
        "id",
        "addFeed",
        "url",
        "removeFeed",
        "feed",
        "removeFeeds",
        "QVariantList",
        "feedsVariantList",
        "lastPlayingEntry",
        "setLastPlayingEntry",
        "deletePlayedEnclosures",
        "importFeeds",
        "path",
        "exportFeeds",
        "feedExists",
        "bulkMarkRead",
        "bulkMarkNew",
        "bulkMarkFavorite",
        "bulkQueueStatus",
        "bulkDownloadEnclosures",
        "bulkDeleteEnclosures",
        "bulkSetPlayPositions",
        "playPositions",
        "bulkSetEnclosureDurations",
        "bulkSetEnclosureSizes",
        "bulkSetEnclosureStatuses",
        "bulkMarkReadByIndex",
        "QModelIndexList",
        "list",
        "bulkMarkNewByIndex",
        "bulkMarkFavoriteByIndex",
        "bulkQueueStatusByIndex",
        "bulkDownloadEnclosuresByIndex",
        "bulkDeleteEnclosuresByIndex"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'feedAdded'
        QtMocHelpers::SignalData<void(const qint64)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Signal 'feedRemoved'
        QtMocHelpers::SignalData<void(const qint64)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Signal 'feedEntriesUpdated'
        QtMocHelpers::SignalData<void(const qint64)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Signal 'entryReadStatusChanged'
        QtMocHelpers::SignalData<void(bool, const QList<qint64> &) const>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'entryNewStatusChanged'
        QtMocHelpers::SignalData<void(bool, const QList<qint64> &) const>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'entryFavoriteStatusChanged'
        QtMocHelpers::SignalData<void(bool, const QList<qint64> &) const>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'entryQueueStatusChanged'
        QtMocHelpers::SignalData<void(bool, const QList<qint64> &) const>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'entryPlayPositionsChanged'
        QtMocHelpers::SignalData<void(const QList<qint64> &, const QList<qint64> &) const>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 18 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'enclosureDurationsChanged'
        QtMocHelpers::SignalData<void(const QList<qint64> &, const QList<qint64> &) const>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 20 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'enclosureSizesChanged'
        QtMocHelpers::SignalData<void(const QList<qint64> &, const QList<qint64> &) const>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 22 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'enclosureStatusesChanged'
        QtMocHelpers::SignalData<void(const QList<Enclosure::Status> &, const QList<qint64> &) const>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'unreadEntryCountChanged'
        QtMocHelpers::SignalData<void(const qint64) const>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Signal 'newEntryCountChanged'
        QtMocHelpers::SignalData<void(const qint64) const>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Signal 'favoriteEntryCountChanged'
        QtMocHelpers::SignalData<void(const qint64) const>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Method 'getFeed'
        QtMocHelpers::MethodData<Feed *(const qint64) const>(29, 6, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Method 'getEntry'
        QtMocHelpers::MethodData<Entry *(const qint64) const>(31, 6, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::LongLong, 33 },
        }}),
        // Method 'getFeed'
        QtMocHelpers::MethodData<Feed *(const QString &) const>(29, 6, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::QString, 34 },
        }}),
        // Method 'getEntry'
        QtMocHelpers::MethodData<Entry *(const QString &) const>(31, 6, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::QString, 35 },
        }}),
        // Method 'addFeed'
        QtMocHelpers::MethodData<void(const QString &)>(36, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Method 'removeFeed'
        QtMocHelpers::MethodData<void(Feed *)>(38, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 39 },
        }}),
        // Method 'removeFeeds'
        QtMocHelpers::MethodData<void(const QVariantList)>(40, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Method 'lastPlayingEntry'
        QtMocHelpers::MethodData<qint64()>(43, 6, QMC::AccessPublic, QMetaType::LongLong),
        // Method 'setLastPlayingEntry'
        QtMocHelpers::MethodData<void(const qint64)>(44, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 33 },
        }}),
        // Method 'deletePlayedEnclosures'
        QtMocHelpers::MethodData<void()>(45, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'importFeeds'
        QtMocHelpers::MethodData<void(const QString &)>(46, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 47 },
        }}),
        // Method 'exportFeeds'
        QtMocHelpers::MethodData<void(const QString &)>(48, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 47 },
        }}),
        // Method 'feedExists'
        QtMocHelpers::MethodData<bool(const QString &)>(49, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 37 },
        }}),
        // Method 'bulkMarkRead'
        QtMocHelpers::MethodData<void(bool, const QList<qint64> &) const>(50, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'bulkMarkNew'
        QtMocHelpers::MethodData<void(bool, const QList<qint64> &) const>(51, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'bulkMarkFavorite'
        QtMocHelpers::MethodData<void(bool, const QList<qint64> &) const>(52, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'bulkQueueStatus'
        QtMocHelpers::MethodData<void(bool, const QList<qint64> &) const>(53, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'bulkDownloadEnclosures'
        QtMocHelpers::MethodData<void(const QList<qint64> &) const>(54, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'bulkDeleteEnclosures'
        QtMocHelpers::MethodData<void(const QList<qint64> &) const>(55, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'bulkSetPlayPositions'
        QtMocHelpers::MethodData<void(const QList<qint64> &, const QList<qint64> &) const>(56, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 57 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'bulkSetEnclosureDurations'
        QtMocHelpers::MethodData<void(const QList<qint64> &, const QList<qint64> &) const>(58, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 20 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'bulkSetEnclosureSizes'
        QtMocHelpers::MethodData<void(const QList<qint64> &, const QList<qint64> &) const>(59, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 22 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'bulkSetEnclosureStatuses'
        QtMocHelpers::MethodData<void(const QList<Enclosure::Status> &, const QList<qint64> &) const>(60, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'bulkMarkReadByIndex'
        QtMocHelpers::MethodData<void(bool, const QModelIndexList &) const>(61, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 62, 63 },
        }}),
        // Method 'bulkMarkNewByIndex'
        QtMocHelpers::MethodData<void(bool, const QModelIndexList &) const>(64, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 62, 63 },
        }}),
        // Method 'bulkMarkFavoriteByIndex'
        QtMocHelpers::MethodData<void(bool, const QModelIndexList &) const>(65, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 62, 63 },
        }}),
        // Method 'bulkQueueStatusByIndex'
        QtMocHelpers::MethodData<void(bool, const QModelIndexList &) const>(66, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 62, 63 },
        }}),
        // Method 'bulkDownloadEnclosuresByIndex'
        QtMocHelpers::MethodData<void(const QModelIndexList &) const>(67, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 62, 63 },
        }}),
        // Method 'bulkDeleteEnclosuresByIndex'
        QtMocHelpers::MethodData<void(const QModelIndexList &) const>(68, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 62, 63 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DataManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DataManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DataManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DataManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DataManagerE_t>.metaTypes,
    nullptr
} };

void DataManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DataManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->feedAdded((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 1: _t->feedRemoved((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 2: _t->feedEntriesUpdated((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 3: _t->entryReadStatusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 4: _t->entryNewStatusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 5: _t->entryFavoriteStatusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 6: _t->entryQueueStatusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 7: _t->entryPlayPositionsChanged((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 8: _t->enclosureDurationsChanged((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 9: _t->enclosureSizesChanged((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 10: _t->enclosureStatusesChanged((*reinterpret_cast<std::add_pointer_t<QList<Enclosure::Status>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 11: _t->unreadEntryCountChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 12: _t->newEntryCountChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 13: _t->favoriteEntryCountChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 14: { Feed* _r = _t->getFeed((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Feed**>(_a[0]) = std::move(_r); }  break;
        case 15: { Entry* _r = _t->getEntry((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Entry**>(_a[0]) = std::move(_r); }  break;
        case 16: { Feed* _r = _t->getFeed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Feed**>(_a[0]) = std::move(_r); }  break;
        case 17: { Entry* _r = _t->getEntry((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Entry**>(_a[0]) = std::move(_r); }  break;
        case 18: _t->addFeed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->removeFeed((*reinterpret_cast<std::add_pointer_t<Feed*>>(_a[1]))); break;
        case 20: _t->removeFeeds((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 21: { qint64 _r = _t->lastPlayingEntry();
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->setLastPlayingEntry((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 23: _t->deletePlayedEnclosures(); break;
        case 24: _t->importFeeds((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->exportFeeds((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: { bool _r = _t->feedExists((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->bulkMarkRead((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 28: _t->bulkMarkNew((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 29: _t->bulkMarkFavorite((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 30: _t->bulkQueueStatus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 31: _t->bulkDownloadEnclosures((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1]))); break;
        case 32: _t->bulkDeleteEnclosures((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1]))); break;
        case 33: _t->bulkSetPlayPositions((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 34: _t->bulkSetEnclosureDurations((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 35: _t->bulkSetEnclosureSizes((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 36: _t->bulkSetEnclosureStatuses((*reinterpret_cast<std::add_pointer_t<QList<Enclosure::Status>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[2]))); break;
        case 37: _t->bulkMarkReadByIndex((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndexList>>(_a[2]))); break;
        case 38: _t->bulkMarkNewByIndex((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndexList>>(_a[2]))); break;
        case 39: _t->bulkMarkFavoriteByIndex((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndexList>>(_a[2]))); break;
        case 40: _t->bulkQueueStatusByIndex((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndexList>>(_a[2]))); break;
        case 41: _t->bulkDownloadEnclosuresByIndex((*reinterpret_cast<std::add_pointer_t<QModelIndexList>>(_a[1]))); break;
        case 42: _t->bulkDeleteEnclosuresByIndex((*reinterpret_cast<std::add_pointer_t<QModelIndexList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Feed* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QModelIndexList >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QModelIndexList >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QModelIndexList >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QModelIndexList >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QModelIndexList >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QModelIndexList >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(const qint64 )>(_a, &DataManager::feedAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(const qint64 )>(_a, &DataManager::feedRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(const qint64 )>(_a, &DataManager::feedEntriesUpdated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(bool , const QList<qint64> & ) const>(_a, &DataManager::entryReadStatusChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(bool , const QList<qint64> & ) const>(_a, &DataManager::entryNewStatusChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(bool , const QList<qint64> & ) const>(_a, &DataManager::entryFavoriteStatusChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(bool , const QList<qint64> & ) const>(_a, &DataManager::entryQueueStatusChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(const QList<qint64> & , const QList<qint64> & ) const>(_a, &DataManager::entryPlayPositionsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(const QList<qint64> & , const QList<qint64> & ) const>(_a, &DataManager::enclosureDurationsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(const QList<qint64> & , const QList<qint64> & ) const>(_a, &DataManager::enclosureSizesChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(const QList<Enclosure::Status> & , const QList<qint64> & ) const>(_a, &DataManager::enclosureStatusesChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(const qint64 ) const>(_a, &DataManager::unreadEntryCountChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(const qint64 ) const>(_a, &DataManager::newEntryCountChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataManager::*)(const qint64 ) const>(_a, &DataManager::favoriteEntryCountChanged, 13))
            return;
    }
}

const QMetaObject *DataManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DataManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DataManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DataManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    return _id;
}

// SIGNAL 0
void DataManager::feedAdded(const qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DataManager::feedRemoved(const qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DataManager::feedEntriesUpdated(const qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DataManager::entryReadStatusChanged(bool _t1, const QList<qint64> & _t2)const
{
    QMetaObject::activate<void>(const_cast< DataManager *>(this), &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void DataManager::entryNewStatusChanged(bool _t1, const QList<qint64> & _t2)const
{
    QMetaObject::activate<void>(const_cast< DataManager *>(this), &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void DataManager::entryFavoriteStatusChanged(bool _t1, const QList<qint64> & _t2)const
{
    QMetaObject::activate<void>(const_cast< DataManager *>(this), &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void DataManager::entryQueueStatusChanged(bool _t1, const QList<qint64> & _t2)const
{
    QMetaObject::activate<void>(const_cast< DataManager *>(this), &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void DataManager::entryPlayPositionsChanged(const QList<qint64> & _t1, const QList<qint64> & _t2)const
{
    QMetaObject::activate<void>(const_cast< DataManager *>(this), &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void DataManager::enclosureDurationsChanged(const QList<qint64> & _t1, const QList<qint64> & _t2)const
{
    QMetaObject::activate<void>(const_cast< DataManager *>(this), &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void DataManager::enclosureSizesChanged(const QList<qint64> & _t1, const QList<qint64> & _t2)const
{
    QMetaObject::activate<void>(const_cast< DataManager *>(this), &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void DataManager::enclosureStatusesChanged(const QList<Enclosure::Status> & _t1, const QList<qint64> & _t2)const
{
    QMetaObject::activate<void>(const_cast< DataManager *>(this), &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void DataManager::unreadEntryCountChanged(const qint64 _t1)const
{
    QMetaObject::activate<void>(const_cast< DataManager *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DataManager::newEntryCountChanged(const qint64 _t1)const
{
    QMetaObject::activate<void>(const_cast< DataManager *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DataManager::favoriteEntryCountChanged(const qint64 _t1)const
{
    QMetaObject::activate<void>(const_cast< DataManager *>(this), &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
