/****************************************************************************
** Meta object code from reading C++ file 'audiomanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/audiomanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'audiomanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12AudioManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto AudioManager::qt_create_metaobjectdata<qt_meta_tag_ZN12AudioManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AudioManager",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "currentBackendChanged",
        "",
        "KMediaSession::MediaBackends",
        "backend",
        "entryuidChanged",
        "entryuid",
        "entryChanged",
        "Entry*",
        "entry",
        "mutedChanged",
        "muted",
        "volumeChanged",
        "sourceChanged",
        "statusChanged",
        "KMediaSession::MediaStatus",
        "status",
        "playbackStateChanged",
        "KMediaSession::PlaybackState",
        "state",
        "playbackRateChanged",
        "rate",
        "errorChanged",
        "KMediaSession::Error",
        "error",
        "durationChanged",
        "duration",
        "positionChanged",
        "position",
        "seekableChanged",
        "seekable",
        "canPlayChanged",
        "canPauseChanged",
        "canSkipForwardChanged",
        "canSkipBackwardChanged",
        "canGoNextChanged",
        "sleepTimerChanged",
        "remainingSleepTimeChanged",
        "isStreamingChanged",
        "logError",
        "Error::Type",
        "type",
        "url",
        "id",
        "errorId",
        "errorString",
        "title",
        "raiseWindowRequested",
        "quitRequested",
        "setCurrentBackend",
        "setEntryuid",
        "setEntry",
        "setMuted",
        "setVolume",
        "volume",
        "setPosition",
        "setPlaybackRate",
        "play",
        "pause",
        "playPause",
        "stop",
        "seek",
        "skipBackward",
        "skipForward",
        "next",
        "setSleepTimer",
        "stopSleepTimer",
        "mediaStatusChanged",
        "playerDurationChanged",
        "playerMutedChanged",
        "playerVolumeChanged",
        "savePlayPositionToDB",
        "setEntryInfo",
        "prepareAudio",
        "QUrl",
        "loadUrl",
        "checkForPendingSeek",
        "updateMetaData",
        "backendName",
        "currentBackend",
        "availableBackends",
        "QList<KMediaSession::MediaBackends>",
        "playbackState",
        "playbackRate",
        "canPlay",
        "canSkipForward",
        "canSkipBackward",
        "canGoNext",
        "formattedLeftDuration",
        "formattedDuration",
        "formattedPosition",
        "sleepTime",
        "remainingSleepTime",
        "formattedRemainingSleepTime",
        "isStreaming"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentBackendChanged'
        QtMocHelpers::SignalData<void(KMediaSession::MediaBackends)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'entryuidChanged'
        QtMocHelpers::SignalData<void(const qint64)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 10 },
        }}),
        // Signal 'entryChanged'
        QtMocHelpers::SignalData<void(Entry *)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'mutedChanged'
        QtMocHelpers::SignalData<void(const bool)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(const KMediaSession::MediaStatus)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'playbackStateChanged'
        QtMocHelpers::SignalData<void(const KMediaSession::PlaybackState)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Signal 'playbackRateChanged'
        QtMocHelpers::SignalData<void(const qreal)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 25 },
        }}),
        // Signal 'errorChanged'
        QtMocHelpers::SignalData<void(const KMediaSession::Error)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void(const qint64, const qint64)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 30 }, { QMetaType::LongLong, 10 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(const qint64, const qint64)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 32 }, { QMetaType::LongLong, 10 },
        }}),
        // Signal 'seekableChanged'
        QtMocHelpers::SignalData<void(const bool)>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Signal 'canPlayChanged'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canPauseChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSkipForwardChanged'
        QtMocHelpers::SignalData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSkipBackwardChanged'
        QtMocHelpers::SignalData<void()>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canGoNextChanged'
        QtMocHelpers::SignalData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sleepTimerChanged'
        QtMocHelpers::SignalData<void(const qint64)>(40, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 30 },
        }}),
        // Signal 'remainingSleepTimeChanged'
        QtMocHelpers::SignalData<void(const qint64)>(41, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 30 },
        }}),
        // Signal 'isStreamingChanged'
        QtMocHelpers::SignalData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'logError'
        QtMocHelpers::SignalData<void(const Error::Type, const QString &, const QString &, const int, const QString &, const QString &)>(43, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 45 }, { QMetaType::QString, 46 }, { QMetaType::QString, 47 }, { QMetaType::Int, 48 },
            { QMetaType::QString, 49 }, { QMetaType::QString, 50 },
        }}),
        // Signal 'raiseWindowRequested'
        QtMocHelpers::SignalData<void()>(51, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'quitRequested'
        QtMocHelpers::SignalData<void()>(52, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCurrentBackend'
        QtMocHelpers::SlotData<void(const KMediaSession::MediaBackends)>(53, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'setEntryuid'
        QtMocHelpers::SlotData<void(const qint64)>(54, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 10 },
        }}),
        // Slot 'setEntry'
        QtMocHelpers::SlotData<void(Entry *)>(55, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setMuted'
        QtMocHelpers::SlotData<void(const bool)>(56, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'setVolume'
        QtMocHelpers::SlotData<void(const qreal)>(57, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 58 },
        }}),
        // Slot 'setPosition'
        QtMocHelpers::SlotData<void(const qint64)>(59, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 32 },
        }}),
        // Slot 'setPlaybackRate'
        QtMocHelpers::SlotData<void(const qreal)>(60, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 25 },
        }}),
        // Slot 'play'
        QtMocHelpers::SlotData<void()>(61, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(62, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playPause'
        QtMocHelpers::SlotData<void()>(63, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(64, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seek'
        QtMocHelpers::SlotData<void(const qint64)>(65, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 32 },
        }}),
        // Slot 'skipBackward'
        QtMocHelpers::SlotData<void()>(66, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'skipForward'
        QtMocHelpers::SlotData<void()>(67, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'next'
        QtMocHelpers::SlotData<void()>(68, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSleepTimer'
        QtMocHelpers::SlotData<void(const qint64)>(69, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 30 },
        }}),
        // Slot 'stopSleepTimer'
        QtMocHelpers::SlotData<void()>(70, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mediaStatusChanged'
        QtMocHelpers::SlotData<void()>(71, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playerDurationChanged'
        QtMocHelpers::SlotData<void(const qint64)>(72, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 30 },
        }}),
        // Slot 'playerMutedChanged'
        QtMocHelpers::SlotData<void()>(73, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playerVolumeChanged'
        QtMocHelpers::SlotData<void()>(74, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'savePlayPositionToDB'
        QtMocHelpers::SlotData<void(const qint64, const qint64)>(75, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 32 }, { QMetaType::LongLong, 10 },
        }}),
        // Slot 'setEntryInfo'
        QtMocHelpers::SlotData<void(Entry *)>(76, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'prepareAudio'
        QtMocHelpers::SlotData<void(const QUrl &)>(77, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 78, 79 },
        }}),
        // Slot 'checkForPendingSeek'
        QtMocHelpers::SlotData<void()>(80, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMetaData'
        QtMocHelpers::SlotData<void()>(81, 6, QMC::AccessPrivate, QMetaType::Void),
        // Method 'backendName'
        QtMocHelpers::MethodData<QString(KMediaSession::MediaBackends) const>(82, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'currentBackend'
        QtMocHelpers::PropertyData<KMediaSession::MediaBackends>(83, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'availableBackends'
        QtMocHelpers::PropertyData<QList<KMediaSession::MediaBackends>>(84, 0x80000000 | 85, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'entryuid'
        QtMocHelpers::PropertyData<qint64>(10, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'entry'
        QtMocHelpers::PropertyData<Entry*>(13, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'muted'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'volume'
        QtMocHelpers::PropertyData<qreal>(58, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'status'
        QtMocHelpers::PropertyData<KMediaSession::MediaStatus>(20, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'playbackState'
        QtMocHelpers::PropertyData<KMediaSession::PlaybackState>(86, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'playbackRate'
        QtMocHelpers::PropertyData<qreal>(87, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'error'
        QtMocHelpers::PropertyData<KMediaSession::Error>(28, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'duration'
        QtMocHelpers::PropertyData<qint64>(30, QMetaType::LongLong, QMC::DefaultPropertyFlags, 10),
        // property 'position'
        QtMocHelpers::PropertyData<qint64>(32, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'seekable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
        // property 'canPlay'
        QtMocHelpers::PropertyData<bool>(88, QMetaType::Bool, QMC::DefaultPropertyFlags, 13),
        // property 'canSkipForward'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags, 15),
        // property 'canSkipBackward'
        QtMocHelpers::PropertyData<bool>(90, QMetaType::Bool, QMC::DefaultPropertyFlags, 16),
        // property 'canGoNext'
        QtMocHelpers::PropertyData<bool>(91, QMetaType::Bool, QMC::DefaultPropertyFlags, 17),
        // property 'formattedLeftDuration'
        QtMocHelpers::PropertyData<QString>(92, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'formattedDuration'
        QtMocHelpers::PropertyData<QString>(93, QMetaType::QString, QMC::DefaultPropertyFlags, 10),
        // property 'formattedPosition'
        QtMocHelpers::PropertyData<QString>(94, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'sleepTime'
        QtMocHelpers::PropertyData<qint64>(95, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable, 18),
        // property 'remainingSleepTime'
        QtMocHelpers::PropertyData<qint64>(96, QMetaType::LongLong, QMC::DefaultPropertyFlags, 19),
        // property 'formattedRemainingSleepTime'
        QtMocHelpers::PropertyData<QString>(97, QMetaType::QString, QMC::DefaultPropertyFlags, 19),
        // property 'isStreaming'
        QtMocHelpers::PropertyData<bool>(98, QMetaType::Bool, QMC::DefaultPropertyFlags, 20),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<AudioManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN12AudioManagerE[] = {
    QMetaObject::SuperData::link<KMediaSession::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject AudioManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AudioManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AudioManagerE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN12AudioManagerE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12AudioManagerE_t>.metaTypes,
    nullptr
} };

void AudioManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AudioManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentBackendChanged((*reinterpret_cast<std::add_pointer_t<KMediaSession::MediaBackends>>(_a[1]))); break;
        case 1: _t->entryuidChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 2: _t->entryChanged((*reinterpret_cast<std::add_pointer_t<Entry*>>(_a[1]))); break;
        case 3: _t->mutedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->volumeChanged(); break;
        case 5: _t->sourceChanged(); break;
        case 6: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<KMediaSession::MediaStatus>>(_a[1]))); break;
        case 7: _t->playbackStateChanged((*reinterpret_cast<std::add_pointer_t<KMediaSession::PlaybackState>>(_a[1]))); break;
        case 8: _t->playbackRateChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 9: _t->errorChanged((*reinterpret_cast<std::add_pointer_t<KMediaSession::Error>>(_a[1]))); break;
        case 10: _t->durationChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 11: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 12: _t->seekableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->canPlayChanged(); break;
        case 14: _t->canPauseChanged(); break;
        case 15: _t->canSkipForwardChanged(); break;
        case 16: _t->canSkipBackwardChanged(); break;
        case 17: _t->canGoNextChanged(); break;
        case 18: _t->sleepTimerChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 19: _t->remainingSleepTimeChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 20: _t->isStreamingChanged(); break;
        case 21: _t->logError((*reinterpret_cast<std::add_pointer_t<Error::Type>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 22: _t->raiseWindowRequested(); break;
        case 23: _t->quitRequested(); break;
        case 24: _t->setCurrentBackend((*reinterpret_cast<std::add_pointer_t<KMediaSession::MediaBackends>>(_a[1]))); break;
        case 25: _t->setEntryuid((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 26: _t->setEntry((*reinterpret_cast<std::add_pointer_t<Entry*>>(_a[1]))); break;
        case 27: _t->setMuted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->setVolume((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 29: _t->setPosition((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 30: _t->setPlaybackRate((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 31: _t->play(); break;
        case 32: _t->pause(); break;
        case 33: _t->playPause(); break;
        case 34: _t->stop(); break;
        case 35: _t->seek((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 36: _t->skipBackward(); break;
        case 37: _t->skipForward(); break;
        case 38: _t->next(); break;
        case 39: _t->setSleepTimer((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 40: _t->stopSleepTimer(); break;
        case 41: _t->mediaStatusChanged(); break;
        case 42: _t->playerDurationChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 43: _t->playerMutedChanged(); break;
        case 44: _t->playerVolumeChanged(); break;
        case 45: _t->savePlayPositionToDB((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 46: _t->setEntryInfo((*reinterpret_cast<std::add_pointer_t<Entry*>>(_a[1]))); break;
        case 47: _t->prepareAudio((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 48: _t->checkForPendingSeek(); break;
        case 49: _t->updateMetaData(); break;
        case 50: { QString _r = _t->backendName((*reinterpret_cast<std::add_pointer_t<KMediaSession::MediaBackends>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Entry* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Entry* >(); break;
            }
            break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Entry* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(KMediaSession::MediaBackends )>(_a, &AudioManager::currentBackendChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(const qint64 )>(_a, &AudioManager::entryuidChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(Entry * )>(_a, &AudioManager::entryChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(const bool )>(_a, &AudioManager::mutedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)()>(_a, &AudioManager::volumeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)()>(_a, &AudioManager::sourceChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(const KMediaSession::MediaStatus )>(_a, &AudioManager::statusChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(const KMediaSession::PlaybackState )>(_a, &AudioManager::playbackStateChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(const qreal )>(_a, &AudioManager::playbackRateChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(const KMediaSession::Error )>(_a, &AudioManager::errorChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(const qint64 , const qint64 )>(_a, &AudioManager::durationChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(const qint64 , const qint64 )>(_a, &AudioManager::positionChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(const bool )>(_a, &AudioManager::seekableChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)()>(_a, &AudioManager::canPlayChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)()>(_a, &AudioManager::canPauseChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)()>(_a, &AudioManager::canSkipForwardChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)()>(_a, &AudioManager::canSkipBackwardChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)()>(_a, &AudioManager::canGoNextChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(const qint64 )>(_a, &AudioManager::sleepTimerChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(const qint64 )>(_a, &AudioManager::remainingSleepTimeChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)()>(_a, &AudioManager::isStreamingChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)(const Error::Type , const QString & , const QString & , const int , const QString & , const QString & )>(_a, &AudioManager::logError, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)()>(_a, &AudioManager::raiseWindowRequested, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioManager::*)()>(_a, &AudioManager::quitRequested, 23))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Entry* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KMediaSession::MediaBackends*>(_v) = _t->currentBackend(); break;
        case 1: *reinterpret_cast<QList<KMediaSession::MediaBackends>*>(_v) = _t->availableBackends(); break;
        case 2: *reinterpret_cast<qint64*>(_v) = _t->entryuid(); break;
        case 3: *reinterpret_cast<Entry**>(_v) = _t->entry(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->muted(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->volume(); break;
        case 6: *reinterpret_cast<KMediaSession::MediaStatus*>(_v) = _t->status(); break;
        case 7: *reinterpret_cast<KMediaSession::PlaybackState*>(_v) = _t->playbackState(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->playbackRate(); break;
        case 9: *reinterpret_cast<KMediaSession::Error*>(_v) = _t->error(); break;
        case 10: *reinterpret_cast<qint64*>(_v) = _t->duration(); break;
        case 11: *reinterpret_cast<qint64*>(_v) = _t->position(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->seekable(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->canPlay(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->canSkipForward(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->canSkipBackward(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->canGoNext(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->formattedLeftDuration(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->formattedDuration(); break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->formattedPosition(); break;
        case 20: *reinterpret_cast<qint64*>(_v) = _t->sleepTime(); break;
        case 21: *reinterpret_cast<qint64*>(_v) = _t->remainingSleepTime(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->formattedRemainingSleepTime(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->isStreaming(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCurrentBackend(*reinterpret_cast<KMediaSession::MediaBackends*>(_v)); break;
        case 2: _t->setEntryuid(*reinterpret_cast<qint64*>(_v)); break;
        case 3: _t->setEntry(*reinterpret_cast<Entry**>(_v)); break;
        case 4: _t->setMuted(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setVolume(*reinterpret_cast<qreal*>(_v)); break;
        case 8: _t->setPlaybackRate(*reinterpret_cast<qreal*>(_v)); break;
        case 11: _t->setPosition(*reinterpret_cast<qint64*>(_v)); break;
        case 20: _t->setSleepTimer(*reinterpret_cast<qint64*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 20: _t->stopSleepTimer(); break;
        default: break;
        }
    }
}

const QMetaObject *AudioManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AudioManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AudioManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AudioManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void AudioManager::currentBackendChanged(KMediaSession::MediaBackends _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AudioManager::entryuidChanged(const qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AudioManager::entryChanged(Entry * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AudioManager::mutedChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AudioManager::volumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AudioManager::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AudioManager::statusChanged(const KMediaSession::MediaStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void AudioManager::playbackStateChanged(const KMediaSession::PlaybackState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void AudioManager::playbackRateChanged(const qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void AudioManager::errorChanged(const KMediaSession::Error _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void AudioManager::durationChanged(const qint64 _t1, const qint64 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void AudioManager::positionChanged(const qint64 _t1, const qint64 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void AudioManager::seekableChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void AudioManager::canPlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void AudioManager::canPauseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void AudioManager::canSkipForwardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void AudioManager::canSkipBackwardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void AudioManager::canGoNextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void AudioManager::sleepTimerChanged(const qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void AudioManager::remainingSleepTimeChanged(const qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void AudioManager::isStreamingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void AudioManager::logError(const Error::Type _t1, const QString & _t2, const QString & _t3, const int _t4, const QString & _t5, const QString & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 22
void AudioManager::raiseWindowRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void AudioManager::quitRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}
QT_WARNING_POP
