// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "qtmediabackendlogging.h"


Q_LOGGING_CATEGORY(QtMediaBackendLog, "org.kde.kmediasession.qtmediabackend", QtInfoMsg)

