/****************************************************************************
** Meta object code from reading C++ file 'feed.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/feed.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'feed.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4FeedE_t {};
} // unnamed namespace

template <> constexpr inline auto Feed::qt_create_metaobjectdata<qt_meta_tag_ZN4FeedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Feed",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "nameChanged",
        "name",
        "imageChanged",
        "image",
        "cachedImageChanged",
        "imagePath",
        "linkChanged",
        "link",
        "descriptionChanged",
        "description",
        "authorsChanged",
        "authors",
        "lastUpdatedChanged",
        "lastUpdated",
        "dirnameChanged",
        "dirname",
        "entryCountChanged",
        "unreadEntryCountChanged",
        "newEntryCountChanged",
        "favoriteEntryCountChanged",
        "errorIdChanged",
        "errorId",
        "errorStringChanged",
        "errorString",
        "refreshingChanged",
        "refreshing",
        "refresh",
        "feeduid",
        "url",
        "cachedImage",
        "subscribed",
        "entryCount",
        "unreadEntryCount",
        "newEntryCount",
        "favoriteEntryCount",
        "entries",
        "EntriesProxyModel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'imageChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'cachedImageChanged'
        QtMocHelpers::SignalData<void(const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'linkChanged'
        QtMocHelpers::SignalData<void(const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'descriptionChanged'
        QtMocHelpers::SignalData<void(const QString &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Signal 'authorsChanged'
        QtMocHelpers::SignalData<void(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Signal 'lastUpdatedChanged'
        QtMocHelpers::SignalData<void(const QDateTime &)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 20 },
        }}),
        // Signal 'dirnameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Signal 'entryCountChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unreadEntryCountChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newEntryCountChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'favoriteEntryCountChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorIdChanged'
        QtMocHelpers::SignalData<void(int)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Signal 'errorStringChanged'
        QtMocHelpers::SignalData<void(const QString &)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Signal 'refreshingChanged'
        QtMocHelpers::SignalData<void(bool)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Method 'refresh'
        QtMocHelpers::MethodData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'feeduid'
        QtMocHelpers::PropertyData<qint64>(34, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'url'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'image'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'cachedImage'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'link'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'authors'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'refreshing'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'subscribed'
        QtMocHelpers::PropertyData<QDateTime>(37, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastUpdated'
        QtMocHelpers::PropertyData<QDateTime>(20, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'entryCount'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags, 8),
        // property 'unreadEntryCount'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags, 9),
        // property 'newEntryCount'
        QtMocHelpers::PropertyData<int>(40, QMetaType::Int, QMC::DefaultPropertyFlags, 10),
        // property 'favoriteEntryCount'
        QtMocHelpers::PropertyData<int>(41, QMetaType::Int, QMC::DefaultPropertyFlags, 11),
        // property 'errorId'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'errorString'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'entries'
        QtMocHelpers::PropertyData<EntriesProxyModel*>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Feed, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Feed::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4FeedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4FeedE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4FeedE_t>.metaTypes,
    nullptr
} };

void Feed::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Feed *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->imageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->cachedImageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->linkChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->descriptionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->authorsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->lastUpdatedChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 7: _t->dirnameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->entryCountChanged(); break;
        case 9: _t->unreadEntryCountChanged(); break;
        case 10: _t->newEntryCountChanged(); break;
        case 11: _t->favoriteEntryCountChanged(); break;
        case 12: _t->errorIdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->errorStringChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->refreshingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->refresh(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(const QString & )>(_a, &Feed::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(const QString & )>(_a, &Feed::imageChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(const QString & )>(_a, &Feed::cachedImageChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(const QString & )>(_a, &Feed::linkChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(const QString & )>(_a, &Feed::descriptionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(const QString & )>(_a, &Feed::authorsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(const QDateTime & )>(_a, &Feed::lastUpdatedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(const QString & )>(_a, &Feed::dirnameChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)()>(_a, &Feed::entryCountChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)()>(_a, &Feed::unreadEntryCountChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)()>(_a, &Feed::newEntryCountChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)()>(_a, &Feed::favoriteEntryCountChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(int )>(_a, &Feed::errorIdChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(const QString & )>(_a, &Feed::errorStringChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(bool )>(_a, &Feed::refreshingChanged, 14))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 17:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< EntriesProxyModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qint64*>(_v) = _t->feeduid(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->url(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->image(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->cachedImage(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->link(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->authors(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->refreshing(); break;
        case 9: *reinterpret_cast<QDateTime*>(_v) = _t->subscribed(); break;
        case 10: *reinterpret_cast<QDateTime*>(_v) = _t->lastUpdated(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->entryCount(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->unreadEntryCount(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->newEntryCount(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->favoriteEntryCount(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->errorId(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->errorString(); break;
        case 17: *reinterpret_cast<EntriesProxyModel**>(_v) = _t->m_entries; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 8: _t->setRefreshing(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setLastUpdated(*reinterpret_cast<QDateTime*>(_v)); break;
        case 15: _t->setErrorId(*reinterpret_cast<int*>(_v)); break;
        case 16: _t->setErrorString(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Feed::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Feed::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4FeedE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Feed::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void Feed::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Feed::imageChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Feed::cachedImageChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Feed::linkChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Feed::descriptionChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Feed::authorsChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Feed::lastUpdatedChanged(const QDateTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Feed::dirnameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Feed::entryCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Feed::unreadEntryCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Feed::newEntryCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Feed::favoriteEntryCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Feed::errorIdChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Feed::errorStringChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Feed::refreshingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}
QT_WARNING_POP
