/****************************************************************************
** Meta object code from reading C++ file 'networkconnectionmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/utils/networkconnectionmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'networkconnectionmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24NetworkConnectionManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto NetworkConnectionManager::qt_create_metaobjectdata<qt_meta_tag_ZN24NetworkConnectionManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NetworkConnectionManager",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "networkReachableChanged",
        "",
        "feedUpdatesAllowedChanged",
        "episodeDownloadsAllowedChanged",
        "imageDownloadsAllowedChanged",
        "streamingAllowedChanged",
        "networkReachable",
        "feedUpdatesAllowed",
        "episodeDownloadsAllowed",
        "imageDownloadsAllowed",
        "streamingAllowed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'networkReachableChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'feedUpdatesAllowedChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'episodeDownloadsAllowedChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageDownloadsAllowedChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'streamingAllowedChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'networkReachable'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'feedUpdatesAllowed'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'episodeDownloadsAllowed'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'imageDownloadsAllowed'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'streamingAllowed'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<NetworkConnectionManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NetworkConnectionManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24NetworkConnectionManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24NetworkConnectionManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24NetworkConnectionManagerE_t>.metaTypes,
    nullptr
} };

void NetworkConnectionManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetworkConnectionManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->networkReachableChanged(); break;
        case 1: _t->feedUpdatesAllowedChanged(); break;
        case 2: _t->episodeDownloadsAllowedChanged(); break;
        case 3: _t->imageDownloadsAllowedChanged(); break;
        case 4: _t->streamingAllowedChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetworkConnectionManager::*)()>(_a, &NetworkConnectionManager::networkReachableChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkConnectionManager::*)()>(_a, &NetworkConnectionManager::feedUpdatesAllowedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkConnectionManager::*)()>(_a, &NetworkConnectionManager::episodeDownloadsAllowedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkConnectionManager::*)()>(_a, &NetworkConnectionManager::imageDownloadsAllowedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkConnectionManager::*)()>(_a, &NetworkConnectionManager::streamingAllowedChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->networkReachable(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->feedUpdatesAllowed(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->episodeDownloadsAllowed(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->imageDownloadsAllowed(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->streamingAllowed(); break;
        default: break;
        }
    }
}

const QMetaObject *NetworkConnectionManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NetworkConnectionManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24NetworkConnectionManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int NetworkConnectionManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void NetworkConnectionManager::networkReachableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NetworkConnectionManager::feedUpdatesAllowedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void NetworkConnectionManager::episodeDownloadsAllowedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void NetworkConnectionManager::imageDownloadsAllowedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void NetworkConnectionManager::streamingAllowedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
