// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "vlcmediabackendlogging.h"


Q_LOGGING_CATEGORY(VlcMediaBackendLog, "org.kde.kmediasession.vlcmediabackend", QtInfoMsg)

