/****************************************************************************
** Meta object code from reading C++ file 'sync.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/sync/sync.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sync.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4SyncE_t {};
} // unnamed namespace

template <> constexpr inline auto Sync::qt_create_metaobjectdata<qt_meta_tag_ZN4SyncE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Sync",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "syncEnabledChanged",
        "",
        "credentialsChanged",
        "deviceChanged",
        "deviceNameChanged",
        "hostnameChanged",
        "providerChanged",
        "deviceCreated",
        "passwordSaveFinished",
        "success",
        "passwordRetrievalFinished",
        "password",
        "passwordInputRequired",
        "loginSucceeded",
        "deviceListReceived",
        "error",
        "Error::Type",
        "type",
        "url",
        "id",
        "errorId",
        "errorString",
        "title",
        "syncProgressChanged",
        "abortSync",
        "login",
        "username",
        "retrieveCredentialsFromConfig",
        "logout",
        "registerNewDevice",
        "caption",
        "linkUpAllDevices",
        "doRegularSync",
        "forceFetchAll",
        "doForceSync",
        "doSyncPushAll",
        "doQuickSync",
        "syncEnabled",
        "device",
        "deviceName",
        "hostname",
        "provider",
        "SyncUtils::Provider",
        "suggestedDevice",
        "suggestedDeviceName",
        "deviceList",
        "QList<SyncUtils::Device>",
        "syncStatus",
        "SyncUtils::SyncStatus",
        "syncProgress",
        "syncProgressTotal",
        "syncProgressText",
        "lastSuccessfulDownloadSync",
        "lastSuccessfulUploadSync"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'syncEnabledChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'credentialsChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deviceChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deviceNameChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hostnameChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'providerChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deviceCreated'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'passwordSaveFinished'
        QtMocHelpers::SignalData<void(bool)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'passwordRetrievalFinished'
        QtMocHelpers::SignalData<void(QString)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Signal 'passwordInputRequired'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loginSucceeded'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deviceListReceived'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void(Error::Type, const QString &, const QString &, const int, const QString &, const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { QMetaType::QString, 23 }, { QMetaType::QString, 24 }, { QMetaType::Int, 25 },
            { QMetaType::QString, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'syncProgressChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abortSync'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'login'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 }, { QMetaType::QString, 16 },
        }}),
        // Method 'retrieveCredentialsFromConfig'
        QtMocHelpers::MethodData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'logout'
        QtMocHelpers::MethodData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'registerNewDevice'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QString &)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 35 }, { QMetaType::QString, 22 },
        }}),
        // Method 'registerNewDevice'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(34, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 35 },
        }}),
        // Method 'linkUpAllDevices'
        QtMocHelpers::MethodData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'doRegularSync'
        QtMocHelpers::MethodData<void(bool)>(37, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Method 'doRegularSync'
        QtMocHelpers::MethodData<void()>(37, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'doForceSync'
        QtMocHelpers::MethodData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'doSyncPushAll'
        QtMocHelpers::MethodData<void()>(40, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'doQuickSync'
        QtMocHelpers::MethodData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'syncEnabled'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'username'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'password'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'device'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'deviceName'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'hostname'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'provider'
        QtMocHelpers::PropertyData<SyncUtils::Provider>(46, 0x80000000 | 47, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'suggestedDevice'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'suggestedDeviceName'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'deviceList'
        QtMocHelpers::PropertyData<QList<SyncUtils::Device>>(50, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
        // property 'syncStatus'
        QtMocHelpers::PropertyData<SyncUtils::SyncStatus>(52, 0x80000000 | 53, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 13),
        // property 'syncProgress'
        QtMocHelpers::PropertyData<int>(54, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 13),
        // property 'syncProgressTotal'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'syncProgressText'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 13),
        // property 'lastSuccessfulDownloadSync'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags, 13),
        // property 'lastSuccessfulUploadSync'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags, 13),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Sync, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN4SyncE[] = {
    QMetaObject::SuperData::link<SyncUtils::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Sync::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4SyncE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4SyncE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN4SyncE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4SyncE_t>.metaTypes,
    nullptr
} };

void Sync::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Sync *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->syncEnabledChanged(); break;
        case 1: _t->credentialsChanged(); break;
        case 2: _t->deviceChanged(); break;
        case 3: _t->deviceNameChanged(); break;
        case 4: _t->hostnameChanged(); break;
        case 5: _t->providerChanged(); break;
        case 6: _t->deviceCreated(); break;
        case 7: _t->passwordSaveFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->passwordRetrievalFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->passwordInputRequired(); break;
        case 10: _t->loginSucceeded(); break;
        case 11: _t->deviceListReceived(); break;
        case 12: _t->error((*reinterpret_cast<std::add_pointer_t<Error::Type>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 13: _t->syncProgressChanged(); break;
        case 14: _t->abortSync(); break;
        case 15: _t->login((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->retrieveCredentialsFromConfig(); break;
        case 17: _t->logout(); break;
        case 18: _t->registerNewDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 19: _t->registerNewDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->linkUpAllDevices(); break;
        case 21: _t->doRegularSync((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->doRegularSync(); break;
        case 23: _t->doForceSync(); break;
        case 24: _t->doSyncPushAll(); break;
        case 25: _t->doQuickSync(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Sync::*)()>(_a, &Sync::syncEnabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)()>(_a, &Sync::credentialsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)()>(_a, &Sync::deviceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)()>(_a, &Sync::deviceNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)()>(_a, &Sync::hostnameChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)()>(_a, &Sync::providerChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)()>(_a, &Sync::deviceCreated, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)(bool )>(_a, &Sync::passwordSaveFinished, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)(QString )>(_a, &Sync::passwordRetrievalFinished, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)()>(_a, &Sync::passwordInputRequired, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)()>(_a, &Sync::loginSucceeded, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)()>(_a, &Sync::deviceListReceived, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)(Error::Type , const QString & , const QString & , const int , const QString & , const QString & )>(_a, &Sync::error, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)()>(_a, &Sync::syncProgressChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sync::*)()>(_a, &Sync::abortSync, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->syncEnabled(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->username(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->password(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->device(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->deviceName(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->hostname(); break;
        case 6: *reinterpret_cast<SyncUtils::Provider*>(_v) = _t->provider(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->suggestedDevice(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->suggestedDeviceName(); break;
        case 9: *reinterpret_cast<QList<SyncUtils::Device>*>(_v) = _t->deviceList(); break;
        case 10: *reinterpret_cast<SyncUtils::SyncStatus*>(_v) = _t->m_syncStatus; break;
        case 11: *reinterpret_cast<int*>(_v) = _t->m_syncProgress; break;
        case 12: *reinterpret_cast<int*>(_v) = _t->m_syncProgressTotal; break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->m_syncProgressText; break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->lastSuccessfulDownloadSync(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->lastSuccessfulUploadSync(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSyncEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setPassword(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setDevice(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setDeviceName(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setHostname(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setProvider(*reinterpret_cast<SyncUtils::Provider*>(_v)); break;
        case 10:
            if (QtMocHelpers::setProperty(_t->m_syncStatus, *reinterpret_cast<SyncUtils::SyncStatus*>(_v)))
                Q_EMIT _t->syncProgressChanged();
            break;
        case 11:
            if (QtMocHelpers::setProperty(_t->m_syncProgress, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->syncProgressChanged();
            break;
        case 13:
            if (QtMocHelpers::setProperty(_t->m_syncProgressText, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->syncProgressChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *Sync::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Sync::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4SyncE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Sync::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void Sync::syncEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Sync::credentialsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Sync::deviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Sync::deviceNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Sync::hostnameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Sync::providerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Sync::deviceCreated()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Sync::passwordSaveFinished(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Sync::passwordRetrievalFinished(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Sync::passwordInputRequired()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Sync::loginSucceeded()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Sync::deviceListReceived()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Sync::error(Error::Type _t1, const QString & _t2, const QString & _t3, const int _t4, const QString & _t5, const QString & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 13
void Sync::syncProgressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Sync::abortSync()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
