/****************************************************************************
** Meta object code from reading C++ file 'updatefeedjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/utils/updatefeedjob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'updatefeedjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13UpdateFeedJobE_t {};
} // unnamed namespace

template <> constexpr inline auto UpdateFeedJob::qt_create_metaobjectdata<qt_meta_tag_ZN13UpdateFeedJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UpdateFeedJob",
        "feedDetailsUpdated",
        "",
        "feeduid",
        "url",
        "name",
        "image",
        "link",
        "description",
        "lastUpdated",
        "dirname",
        "feedUpdated",
        "entryAdded",
        "entryuid",
        "entryUpdated",
        "aborting",
        "finished",
        "error",
        "Error::Type",
        "type",
        "id",
        "errorId",
        "errorString",
        "title"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'feedDetailsUpdated'
        QtMocHelpers::SignalData<void(const qint64, const QString &, const QString &, const QString &, const QString &, const QString &, const QDateTime &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::QDateTime, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'feedUpdated'
        QtMocHelpers::SignalData<void(const qint64)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 },
        }}),
        // Signal 'entryAdded'
        QtMocHelpers::SignalData<void(const qint64)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 13 },
        }}),
        // Signal 'entryUpdated'
        QtMocHelpers::SignalData<void(const qint64)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 13 },
        }}),
        // Signal 'aborting'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void(Error::Type, const QString &, const QString &, const int, const QString &, const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::QString, 4 }, { QMetaType::QString, 20 }, { QMetaType::Int, 21 },
            { QMetaType::QString, 22 }, { QMetaType::QString, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UpdateFeedJob, qt_meta_tag_ZN13UpdateFeedJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UpdateFeedJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UpdateFeedJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UpdateFeedJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13UpdateFeedJobE_t>.metaTypes,
    nullptr
} };

void UpdateFeedJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UpdateFeedJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->feedDetailsUpdated((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8]))); break;
        case 1: _t->feedUpdated((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 2: _t->entryAdded((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 3: _t->entryUpdated((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 4: _t->aborting(); break;
        case 5: _t->finished(); break;
        case 6: _t->error((*reinterpret_cast<std::add_pointer_t<Error::Type>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UpdateFeedJob::*)(const qint64 , const QString & , const QString & , const QString & , const QString & , const QString & , const QDateTime & , const QString & )>(_a, &UpdateFeedJob::feedDetailsUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UpdateFeedJob::*)(const qint64 )>(_a, &UpdateFeedJob::feedUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UpdateFeedJob::*)(const qint64 )>(_a, &UpdateFeedJob::entryAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UpdateFeedJob::*)(const qint64 )>(_a, &UpdateFeedJob::entryUpdated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UpdateFeedJob::*)()>(_a, &UpdateFeedJob::aborting, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UpdateFeedJob::*)()>(_a, &UpdateFeedJob::finished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UpdateFeedJob::*)(Error::Type , const QString & , const QString & , const int , const QString & , const QString & )>(_a, &UpdateFeedJob::error, 6))
            return;
    }
}

const QMetaObject *UpdateFeedJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UpdateFeedJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UpdateFeedJobE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ThreadWeaver::Job"))
        return static_cast< ThreadWeaver::Job*>(this);
    return QObject::qt_metacast(_clname);
}

int UpdateFeedJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void UpdateFeedJob::feedDetailsUpdated(const qint64 _t1, const QString & _t2, const QString & _t3, const QString & _t4, const QString & _t5, const QString & _t6, const QDateTime & _t7, const QString & _t8)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8);
}

// SIGNAL 1
void UpdateFeedJob::feedUpdated(const qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void UpdateFeedJob::entryAdded(const qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void UpdateFeedJob::entryUpdated(const qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void UpdateFeedJob::aborting()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void UpdateFeedJob::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void UpdateFeedJob::error(Error::Type _t1, const QString & _t2, const QString & _t3, const int _t4, const QString & _t5, const QString & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}
QT_WARNING_POP
