// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "enclosuredownloadlogging.h"


Q_LOGGING_CATEGORY(kastsEnclosureDownload, "org.kde.kasts.enclosuredownload", QtInfoMsg)

