/****************************************************************************
** Meta object code from reading C++ file 'enclosure.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kasts-26.04.2/src/enclosure.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'enclosure.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9EnclosureE_t {};
} // unnamed namespace

template <> constexpr inline auto Enclosure::qt_create_metaobjectdata<qt_meta_tag_ZN9EnclosureE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Enclosure",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "typeChanged",
        "type",
        "urlChanged",
        "url",
        "pathChanged",
        "path",
        "statusChanged",
        "Entry*",
        "entry",
        "Status",
        "status",
        "downloadProgressChanged",
        "cancelDownload",
        "playPositionChanged",
        "leftDurationChanged",
        "durationChanged",
        "sizeChanged",
        "sizeOnDiskChanged",
        "downloadError",
        "Error::Type",
        "id",
        "errorId",
        "errorString",
        "title",
        "download",
        "deleteFile",
        "enclosureuid",
        "size",
        "formattedSize",
        "sizeOnDisk",
        "downloadProgress",
        "formattedDownloadSize",
        "cachedEmbeddedImage",
        "playPosition",
        "formattedLeftDuration",
        "formattedPlayPosition",
        "duration",
        "formattedDuration",
        "Error",
        "Downloadable",
        "Downloading",
        "Queued",
        "PartiallyDownloaded",
        "Downloaded"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'pathChanged'
        QtMocHelpers::SignalData<void(const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(Entry *, enum Status)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 16, 17 },
        }}),
        // Signal 'downloadProgressChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cancelDownload'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playPositionChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftDurationChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sizeOnDiskChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'downloadError'
        QtMocHelpers::SignalData<void(const Error::Type, const QString &, const QString &, const int, const QString &, const QString &)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 8 }, { QMetaType::QString, 10 }, { QMetaType::QString, 27 }, { QMetaType::Int, 28 },
            { QMetaType::QString, 29 }, { QMetaType::QString, 30 },
        }}),
        // Method 'download'
        QtMocHelpers::MethodData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'deleteFile'
        QtMocHelpers::MethodData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enclosureuid'
        QtMocHelpers::PropertyData<qint64>(33, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'size'
        QtMocHelpers::PropertyData<qint64>(34, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'formattedSize'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'sizeOnDisk'
        QtMocHelpers::PropertyData<qint64>(36, QMetaType::LongLong, QMC::DefaultPropertyFlags, 10),
        // property 'type'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'url'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'downloadProgress'
        QtMocHelpers::PropertyData<double>(37, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'formattedDownloadSize'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'path'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'cachedEmbeddedImage'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'playPosition'
        QtMocHelpers::PropertyData<qint64>(40, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'formattedLeftDuration'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'formattedPlayPosition'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'duration'
        QtMocHelpers::PropertyData<qint64>(43, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'formattedDuration'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(16, 16, QMC::EnumFlags{}).add({
            {   45, Status::Error },
            {   46, Status::Downloadable },
            {   47, Status::Downloading },
            {   48, Status::Queued },
            {   49, Status::PartiallyDownloaded },
            {   50, Status::Downloaded },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Enclosure, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Enclosure::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9EnclosureE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9EnclosureE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9EnclosureE_t>.metaTypes,
    nullptr
} };

void Enclosure::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Enclosure *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->urlChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->pathChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<Entry*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum Status>>(_a[2]))); break;
        case 4: _t->downloadProgressChanged(); break;
        case 5: _t->cancelDownload(); break;
        case 6: _t->playPositionChanged(); break;
        case 7: _t->leftDurationChanged(); break;
        case 8: _t->durationChanged(); break;
        case 9: _t->sizeChanged(); break;
        case 10: _t->sizeOnDiskChanged(); break;
        case 11: _t->downloadError((*reinterpret_cast<std::add_pointer_t<Error::Type>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 12: _t->download(); break;
        case 13: _t->deleteFile(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Enclosure::*)(const QString & )>(_a, &Enclosure::typeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Enclosure::*)(const QString & )>(_a, &Enclosure::urlChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Enclosure::*)(const QString & )>(_a, &Enclosure::pathChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Enclosure::*)(Entry * , Status )>(_a, &Enclosure::statusChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Enclosure::*)()>(_a, &Enclosure::downloadProgressChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Enclosure::*)()>(_a, &Enclosure::cancelDownload, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Enclosure::*)()>(_a, &Enclosure::playPositionChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Enclosure::*)()>(_a, &Enclosure::leftDurationChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Enclosure::*)()>(_a, &Enclosure::durationChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Enclosure::*)()>(_a, &Enclosure::sizeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Enclosure::*)()>(_a, &Enclosure::sizeOnDiskChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Enclosure::*)(const Error::Type , const QString & , const QString & , const int , const QString & , const QString & )>(_a, &Enclosure::downloadError, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qint64*>(_v) = _t->enclosureuid(); break;
        case 1: *reinterpret_cast<qint64*>(_v) = _t->size(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->formattedSize(); break;
        case 3: *reinterpret_cast<qint64*>(_v) = _t->sizeOnDisk(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_type; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->url(); break;
        case 6: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        case 7: *reinterpret_cast<double*>(_v) = _t->m_downloadProgress; break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->formattedDownloadSize(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->cachedEmbeddedImage(); break;
        case 11: *reinterpret_cast<qint64*>(_v) = _t->playPosition(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->formattedLeftDuration(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->formattedPlayPosition(); break;
        case 14: *reinterpret_cast<qint64*>(_v) = _t->duration(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->formattedDuration(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setSize(*reinterpret_cast<qint64*>(_v)); break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_type, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->typeChanged(_t->m_type);
            break;
        case 6: _t->setStatus(*reinterpret_cast<enum Status*>(_v)); break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_downloadProgress, *reinterpret_cast<double*>(_v)))
                Q_EMIT _t->downloadProgressChanged();
            break;
        case 11: _t->setPlayPosition(*reinterpret_cast<qint64*>(_v)); break;
        case 14: _t->setDuration(*reinterpret_cast<qint64*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Enclosure::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Enclosure::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9EnclosureE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Enclosure::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void Enclosure::typeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Enclosure::urlChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Enclosure::pathChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Enclosure::statusChanged(Entry * _t1, Status _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Enclosure::downloadProgressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Enclosure::cancelDownload()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Enclosure::playPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Enclosure::leftDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Enclosure::durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Enclosure::sizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Enclosure::sizeOnDiskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Enclosure::downloadError(const Error::Type _t1, const QString & _t2, const QString & _t3, const int _t4, const QString & _t5, const QString & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}
QT_WARNING_POP
